/*
 * SPDX-License-Identifier: ODbL-1.0
 * SPDX-FileCopyrightText: OpenStreetMap contributors
 *
 * Autogenerated spatial index generated using QGIS.
 */

#include "spatial_index_property_p.h"
#include "timezone_names_p.h"

static constexpr const SpatialIndexProperty spatial_index_properties[] = {
    {Tz::Undefined},
    {Tz::Undefined, "AU"},
    {Tz::Undefined, "AU-NSW"},
    {Tz::Undefined, "AU-QLD"},
    {Tz::Undefined, "AU-WA"},
    {Tz::Undefined, "BR"},
    {Tz::Undefined, "BR-AM"},
    {Tz::Undefined, "BR-PA"},
    {Tz::Undefined, "BR-PE"},
    {Tz::Undefined, "BR-RN"},
    {Tz::Undefined, "CA"},
    {Tz::Undefined, "CA-BC"},
    {Tz::Undefined, "CA-NL"},
    {Tz::Undefined, "CA-NS"},
    {Tz::Undefined, "CA-NT"},
    {Tz::Undefined, "CA-NU"},
    {Tz::Undefined, "CA-ON"},
    {Tz::Undefined, "CA-QC"},
    {Tz::Undefined, "CA-SK"},
    {Tz::Undefined, "CA-YT"},
    {Tz::Undefined, "CD"},
    {Tz::Undefined, "CL"},
    {Tz::Undefined, "CL-VS"},
    {Tz::Undefined, "CN"},
    {Tz::Undefined, "CN-XJ"},
    {Tz::Undefined, "CN-XZ"},
    {Tz::Undefined, "FR"},
    {Tz::Undefined, "FR-CP"},
    {Tz::Undefined, "GE"},
    {Tz::Undefined, "GE-AB"},
    {Tz::Undefined, "GL"},
    {Tz::Undefined, "GL-AV"},
    {Tz::Undefined, "GL-SM"},
    {Tz::Undefined, "ID"},
    {Tz::Undefined, "KZ"},
    {Tz::Undefined, "MA"},
    {Tz::Undefined, "MA-11"},
    {Tz::Undefined, "MN"},
    {Tz::Undefined, "MX"},
    {Tz::Undefined, "MX-CHH"},
    {Tz::Undefined, "MX-COA"},
    {Tz::Undefined, "MX-NAY"},
    {Tz::Undefined, "MX-NLE"},
    {Tz::Undefined, "MX-TAM"},
    {Tz::Undefined, "PG"},
    {Tz::Undefined, "PG-NIK"},
    {Tz::Undefined, "PS"},
    {Tz::Undefined, "PS-HBN"},
    {Tz::Undefined, "PS-JEN"},
    {Tz::Undefined, "PS-RBH"},
    {Tz::Undefined, "PS-TBS"},
    {Tz::Undefined, "PT"},
    {Tz::Undefined, "RU"},
    {Tz::Undefined, "RU-SA"},
    {Tz::Undefined, "RU-SAK"},
    {Tz::Undefined, "SD"},
    {Tz::Undefined, "SS-BW"},
    {Tz::Undefined, "UA"},
    {Tz::Undefined, "US"},
    {Tz::Undefined, "US-AK"},
    {Tz::Undefined, "US-AZ"},
    {Tz::Undefined, "US-FL"},
    {Tz::Undefined, "US-HI"},
    {Tz::Undefined, "US-ID"},
    {Tz::Undefined, "US-IN"},
    {Tz::Undefined, "US-KY"},
    {Tz::Undefined, "US-MI"},
    {Tz::Undefined, "US-ND"},
    {Tz::Undefined, "US-NE"},
    {Tz::Undefined, "US-OR"},
    {Tz::Undefined, "US-SD"},
    {Tz::Undefined, "US-TN"},
    {Tz::Undefined, "UZ"},
    {Tz::Africa_Abidjan},
    {Tz::Africa_Abidjan, "CI"},
    {Tz::Africa_Abidjan, "CI-AB"},
    {Tz::Africa_Abidjan, "CI-BS"},
    {Tz::Africa_Abidjan, "CI-CM"},
    {Tz::Africa_Abidjan, "CI-DN"},
    {Tz::Africa_Abidjan, "CI-GD"},
    {Tz::Africa_Abidjan, "CI-LC"},
    {Tz::Africa_Abidjan, "CI-LG"},
    {Tz::Africa_Abidjan, "CI-MG"},
    {Tz::Africa_Abidjan, "CI-SM"},
    {Tz::Africa_Abidjan, "CI-SV"},
    {Tz::Africa_Abidjan, "CI-VB"},
    {Tz::Africa_Abidjan, "CI-WR"},
    {Tz::Africa_Abidjan, "CI-YM"},
    {Tz::Africa_Abidjan, "CI-ZZ"},
    {Tz::Africa_Accra},
    {Tz::Africa_Accra, "GH"},
    {Tz::Africa_Accra, "GH-AA"},
    {Tz::Africa_Accra, "GH-AF"},
    {Tz::Africa_Accra, "GH-AH"},
    {Tz::Africa_Accra, "GH-BE"},
    {Tz::Africa_Accra, "GH-BO"},
    {Tz::Africa_Accra, "GH-CP"},
    {Tz::Africa_Accra, "GH-EP"},
    {Tz::Africa_Accra, "GH-NE"},
    {Tz::Africa_Accra, "GH-NP"},
    {Tz::Africa_Accra, "GH-OT"},
    {Tz::Africa_Accra, "GH-SV"},
    {Tz::Africa_Accra, "GH-TV"},
    {Tz::Africa_Accra, "GH-UE"},
    {Tz::Africa_Accra, "GH-UW"},
    {Tz::Africa_Accra, "GH-WN"},
    {Tz::Africa_Accra, "GH-WP"},
    {Tz::Africa_Addis_Ababa},
    {Tz::Africa_Addis_Ababa, "ET"},
    {Tz::Africa_Addis_Ababa, "ET-AA"},
    {Tz::Africa_Addis_Ababa, "ET-AF"},
    {Tz::Africa_Addis_Ababa, "ET-AM"},
    {Tz::Africa_Addis_Ababa, "ET-BE"},
    {Tz::Africa_Addis_Ababa, "ET-DD"},
    {Tz::Africa_Addis_Ababa, "ET-GA"},
    {Tz::Africa_Addis_Ababa, "ET-OR"},
    {Tz::Africa_Addis_Ababa, "ET-SN"},
    {Tz::Africa_Addis_Ababa, "ET-SO"},
    {Tz::Africa_Addis_Ababa, "ET-TI"},
    {Tz::Africa_Algiers},
    {Tz::Africa_Algiers, "DZ"},
    {Tz::Africa_Algiers, "DZ-01"},
    {Tz::Africa_Algiers, "DZ-02"},
    {Tz::Africa_Algiers, "DZ-03"},
    {Tz::Africa_Algiers, "DZ-04"},
    {Tz::Africa_Algiers, "DZ-05"},
    {Tz::Africa_Algiers, "DZ-06"},
    {Tz::Africa_Algiers, "DZ-07"},
    {Tz::Africa_Algiers, "DZ-08"},
    {Tz::Africa_Algiers, "DZ-09"},
    {Tz::Africa_Algiers, "DZ-10"},
    {Tz::Africa_Algiers, "DZ-11"},
    {Tz::Africa_Algiers, "DZ-12"},
    {Tz::Africa_Algiers, "DZ-13"},
    {Tz::Africa_Algiers, "DZ-14"},
    {Tz::Africa_Algiers, "DZ-15"},
    {Tz::Africa_Algiers, "DZ-16"},
    {Tz::Africa_Algiers, "DZ-17"},
    {Tz::Africa_Algiers, "DZ-18"},
    {Tz::Africa_Algiers, "DZ-19"},
    {Tz::Africa_Algiers, "DZ-20"},
    {Tz::Africa_Algiers, "DZ-21"},
    {Tz::Africa_Algiers, "DZ-22"},
    {Tz::Africa_Algiers, "DZ-23"},
    {Tz::Africa_Algiers, "DZ-24"},
    {Tz::Africa_Algiers, "DZ-25"},
    {Tz::Africa_Algiers, "DZ-26"},
    {Tz::Africa_Algiers, "DZ-27"},
    {Tz::Africa_Algiers, "DZ-28"},
    {Tz::Africa_Algiers, "DZ-29"},
    {Tz::Africa_Algiers, "DZ-30"},
    {Tz::Africa_Algiers, "DZ-31"},
    {Tz::Africa_Algiers, "DZ-32"},
    {Tz::Africa_Algiers, "DZ-33"},
    {Tz::Africa_Algiers, "DZ-34"},
    {Tz::Africa_Algiers, "DZ-35"},
    {Tz::Africa_Algiers, "DZ-36"},
    {Tz::Africa_Algiers, "DZ-37"},
    {Tz::Africa_Algiers, "DZ-38"},
    {Tz::Africa_Algiers, "DZ-39"},
    {Tz::Africa_Algiers, "DZ-40"},
    {Tz::Africa_Algiers, "DZ-41"},
    {Tz::Africa_Algiers, "DZ-42"},
    {Tz::Africa_Algiers, "DZ-43"},
    {Tz::Africa_Algiers, "DZ-44"},
    {Tz::Africa_Algiers, "DZ-45"},
    {Tz::Africa_Algiers, "DZ-46"},
    {Tz::Africa_Algiers, "DZ-47"},
    {Tz::Africa_Algiers, "DZ-48"},
    {Tz::Africa_Algiers, "DZ-49"},
    {Tz::Africa_Algiers, "DZ-50"},
    {Tz::Africa_Algiers, "DZ-51"},
    {Tz::Africa_Algiers, "DZ-52"},
    {Tz::Africa_Algiers, "DZ-53"},
    {Tz::Africa_Algiers, "DZ-54"},
    {Tz::Africa_Algiers, "DZ-55"},
    {Tz::Africa_Algiers, "DZ-56"},
    {Tz::Africa_Algiers, "DZ-57"},
    {Tz::Africa_Algiers, "DZ-58"},
    {Tz::Africa_Asmara},
    {Tz::Africa_Asmara, "ER"},
    {Tz::Africa_Asmara, "ER-AN"},
    {Tz::Africa_Asmara, "ER-DK"},
    {Tz::Africa_Asmara, "ER-DU"},
    {Tz::Africa_Asmara, "ER-GB"},
    {Tz::Africa_Asmara, "ER-MA"},
    {Tz::Africa_Asmara, "ER-SK"},
    {Tz::Africa_Bamako},
    {Tz::Africa_Bamako, "ML"},
    {Tz::Africa_Bamako, "ML-1"},
    {Tz::Africa_Bamako, "ML-10"},
    {Tz::Africa_Bamako, "ML-2"},
    {Tz::Africa_Bamako, "ML-3"},
    {Tz::Africa_Bamako, "ML-4"},
    {Tz::Africa_Bamako, "ML-5"},
    {Tz::Africa_Bamako, "ML-6"},
    {Tz::Africa_Bamako, "ML-7"},
    {Tz::Africa_Bamako, "ML-8"},
    {Tz::Africa_Bamako, "ML-9"},
    {Tz::Africa_Bangui},
    {Tz::Africa_Bangui, "CF"},
    {Tz::Africa_Bangui, "CF-AC"},
    {Tz::Africa_Bangui, "CF-BB"},
    {Tz::Africa_Bangui, "CF-BK"},
    {Tz::Africa_Bangui, "CF-HK"},
    {Tz::Africa_Bangui, "CF-HM"},
    {Tz::Africa_Bangui, "CF-HS"},
    {Tz::Africa_Bangui, "CF-KB"},
    {Tz::Africa_Bangui, "CF-KG"},
    {Tz::Africa_Bangui, "CF-LB"},
    {Tz::Africa_Bangui, "CF-MB"},
    {Tz::Africa_Bangui, "CF-MP"},
    {Tz::Africa_Bangui, "CF-NM"},
    {Tz::Africa_Bangui, "CF-OP"},
    {Tz::Africa_Bangui, "CF-SE"},
    {Tz::Africa_Bangui, "CF-UK"},
    {Tz::Africa_Bangui, "CF-VK"},
    {Tz::Africa_Banjul},
    {Tz::Africa_Banjul, "GM"},
    {Tz::Africa_Banjul, "GM-L"},
    {Tz::Africa_Banjul, "GM-M"},
    {Tz::Africa_Banjul, "GM-N"},
    {Tz::Africa_Banjul, "GM-U"},
    {Tz::Africa_Banjul, "GM-W"},
    {Tz::Africa_Bissau},
    {Tz::Africa_Bissau, "GW"},
    {Tz::Africa_Bissau, "GW-L"},
    {Tz::Africa_Bissau, "GW-N"},
    {Tz::Africa_Bissau, "GW-S"},
    {Tz::Africa_Blantyre},
    {Tz::Africa_Blantyre, "MW"},
    {Tz::Africa_Blantyre, "MW-C"},
    {Tz::Africa_Blantyre, "MW-N"},
    {Tz::Africa_Blantyre, "MW-S"},
    {Tz::Africa_Brazzaville},
    {Tz::Africa_Brazzaville, "CG"},
    {Tz::Africa_Brazzaville, "CG-11"},
    {Tz::Africa_Brazzaville, "CG-12"},
    {Tz::Africa_Brazzaville, "CG-13"},
    {Tz::Africa_Brazzaville, "CG-14"},
    {Tz::Africa_Brazzaville, "CG-15"},
    {Tz::Africa_Brazzaville, "CG-16"},
    {Tz::Africa_Brazzaville, "CG-2"},
    {Tz::Africa_Brazzaville, "CG-5"},
    {Tz::Africa_Brazzaville, "CG-7"},
    {Tz::Africa_Brazzaville, "CG-8"},
    {Tz::Africa_Brazzaville, "CG-9"},
    {Tz::Africa_Brazzaville, "CG-BZV"},
    {Tz::Africa_Bujumbura},
    {Tz::Africa_Bujumbura, "BI"},
    {Tz::Africa_Bujumbura, "BI-BB"},
    {Tz::Africa_Bujumbura, "BI-BL"},
    {Tz::Africa_Bujumbura, "BI-CA"},
    {Tz::Africa_Bujumbura, "BI-CI"},
    {Tz::Africa_Bujumbura, "BI-GI"},
    {Tz::Africa_Bujumbura, "BI-KI"},
    {Tz::Africa_Bujumbura, "BI-KR"},
    {Tz::Africa_Bujumbura, "BI-KY"},
    {Tz::Africa_Bujumbura, "BI-MA"},
    {Tz::Africa_Bujumbura, "BI-MU"},
    {Tz::Africa_Bujumbura, "BI-MY"},
    {Tz::Africa_Bujumbura, "BI-NG"},
    {Tz::Africa_Bujumbura, "BI-RM"},
    {Tz::Africa_Bujumbura, "BI-RT"},
    {Tz::Africa_Bujumbura, "BI-RY"},
    {Tz::Africa_Cairo},
    {Tz::Africa_Cairo, "EG"},
    {Tz::Africa_Cairo, "EG-ALX"},
    {Tz::Africa_Cairo, "EG-ASN"},
    {Tz::Africa_Cairo, "EG-AST"},
    {Tz::Africa_Cairo, "EG-BA"},
    {Tz::Africa_Cairo, "EG-BH"},
    {Tz::Africa_Cairo, "EG-BNS"},
    {Tz::Africa_Cairo, "EG-C"},
    {Tz::Africa_Cairo, "EG-DK"},
    {Tz::Africa_Cairo, "EG-DT"},
    {Tz::Africa_Cairo, "EG-FYM"},
    {Tz::Africa_Cairo, "EG-GH"},
    {Tz::Africa_Cairo, "EG-GZ"},
    {Tz::Africa_Cairo, "EG-IS"},
    {Tz::Africa_Cairo, "EG-JS"},
    {Tz::Africa_Cairo, "EG-KB"},
    {Tz::Africa_Cairo, "EG-KFS"},
    {Tz::Africa_Cairo, "EG-KN"},
    {Tz::Africa_Cairo, "EG-LX"},
    {Tz::Africa_Cairo, "EG-MN"},
    {Tz::Africa_Cairo, "EG-MNF"},
    {Tz::Africa_Cairo, "EG-MT"},
    {Tz::Africa_Cairo, "EG-PTS"},
    {Tz::Africa_Cairo, "EG-SHG"},
    {Tz::Africa_Cairo, "EG-SHR"},
    {Tz::Africa_Cairo, "EG-SIN"},
    {Tz::Africa_Cairo, "EG-SUZ"},
    {Tz::Africa_Cairo, "EG-WAD"},
    {Tz::Africa_Casablanca},
    {Tz::Africa_Casablanca, "MA"},
    {Tz::Africa_Casablanca, "MA-01"},
    {Tz::Africa_Casablanca, "MA-02"},
    {Tz::Africa_Casablanca, "MA-03"},
    {Tz::Africa_Casablanca, "MA-04"},
    {Tz::Africa_Casablanca, "MA-05"},
    {Tz::Africa_Casablanca, "MA-06"},
    {Tz::Africa_Casablanca, "MA-07"},
    {Tz::Africa_Casablanca, "MA-08"},
    {Tz::Africa_Casablanca, "MA-09"},
    {Tz::Africa_Casablanca, "MA-10"},
    {Tz::Africa_Casablanca, "MA-11"},
    {Tz::Africa_Conakry},
    {Tz::Africa_Conakry, "GN"},
    {Tz::Africa_Conakry, "GN-B"},
    {Tz::Africa_Conakry, "GN-C"},
    {Tz::Africa_Conakry, "GN-D"},
    {Tz::Africa_Conakry, "GN-F"},
    {Tz::Africa_Conakry, "GN-K"},
    {Tz::Africa_Conakry, "GN-L"},
    {Tz::Africa_Conakry, "GN-M"},
    {Tz::Africa_Conakry, "GN-N"},
    {Tz::Africa_Dakar},
    {Tz::Africa_Dakar, "SN"},
    {Tz::Africa_Dakar, "SN-DB"},
    {Tz::Africa_Dakar, "SN-DK"},
    {Tz::Africa_Dakar, "SN-FK"},
    {Tz::Africa_Dakar, "SN-KA"},
    {Tz::Africa_Dakar, "SN-KD"},
    {Tz::Africa_Dakar, "SN-KE"},
    {Tz::Africa_Dakar, "SN-KL"},
    {Tz::Africa_Dakar, "SN-LG"},
    {Tz::Africa_Dakar, "SN-MT"},
    {Tz::Africa_Dakar, "SN-SE"},
    {Tz::Africa_Dakar, "SN-SL"},
    {Tz::Africa_Dakar, "SN-TC"},
    {Tz::Africa_Dakar, "SN-TH"},
    {Tz::Africa_Dakar, "SN-ZG"},
    {Tz::Africa_Dar_es_Salaam},
    {Tz::Africa_Dar_es_Salaam, "TZ"},
    {Tz::Africa_Dar_es_Salaam, "TZ-01"},
    {Tz::Africa_Dar_es_Salaam, "TZ-02"},
    {Tz::Africa_Dar_es_Salaam, "TZ-03"},
    {Tz::Africa_Dar_es_Salaam, "TZ-04"},
    {Tz::Africa_Dar_es_Salaam, "TZ-05"},
    {Tz::Africa_Dar_es_Salaam, "TZ-06"},
    {Tz::Africa_Dar_es_Salaam, "TZ-07"},
    {Tz::Africa_Dar_es_Salaam, "TZ-08"},
    {Tz::Africa_Dar_es_Salaam, "TZ-09"},
    {Tz::Africa_Dar_es_Salaam, "TZ-10"},
    {Tz::Africa_Dar_es_Salaam, "TZ-11"},
    {Tz::Africa_Dar_es_Salaam, "TZ-12"},
    {Tz::Africa_Dar_es_Salaam, "TZ-13"},
    {Tz::Africa_Dar_es_Salaam, "TZ-14"},
    {Tz::Africa_Dar_es_Salaam, "TZ-15"},
    {Tz::Africa_Dar_es_Salaam, "TZ-16"},
    {Tz::Africa_Dar_es_Salaam, "TZ-17"},
    {Tz::Africa_Dar_es_Salaam, "TZ-18"},
    {Tz::Africa_Dar_es_Salaam, "TZ-19"},
    {Tz::Africa_Dar_es_Salaam, "TZ-20"},
    {Tz::Africa_Dar_es_Salaam, "TZ-21"},
    {Tz::Africa_Dar_es_Salaam, "TZ-22"},
    {Tz::Africa_Dar_es_Salaam, "TZ-23"},
    {Tz::Africa_Dar_es_Salaam, "TZ-24"},
    {Tz::Africa_Dar_es_Salaam, "TZ-25"},
    {Tz::Africa_Dar_es_Salaam, "TZ-26"},
    {Tz::Africa_Dar_es_Salaam, "TZ-27"},
    {Tz::Africa_Dar_es_Salaam, "TZ-28"},
    {Tz::Africa_Dar_es_Salaam, "TZ-29"},
    {Tz::Africa_Dar_es_Salaam, "TZ-30"},
    {Tz::Africa_Dar_es_Salaam, "TZ-31"},
    {Tz::Africa_Djibouti},
    {Tz::Africa_Djibouti, "DJ"},
    {Tz::Africa_Djibouti, "DJ-AR"},
    {Tz::Africa_Djibouti, "DJ-AS"},
    {Tz::Africa_Djibouti, "DJ-DI"},
    {Tz::Africa_Djibouti, "DJ-DJ"},
    {Tz::Africa_Djibouti, "DJ-OB"},
    {Tz::Africa_Djibouti, "DJ-TA"},
    {Tz::Africa_Douala},
    {Tz::Africa_Douala, "CM"},
    {Tz::Africa_Douala, "CM-AD"},
    {Tz::Africa_Douala, "CM-CE"},
    {Tz::Africa_Douala, "CM-EN"},
    {Tz::Africa_Douala, "CM-ES"},
    {Tz::Africa_Douala, "CM-LT"},
    {Tz::Africa_Douala, "CM-NO"},
    {Tz::Africa_Douala, "CM-NW"},
    {Tz::Africa_Douala, "CM-OU"},
    {Tz::Africa_Douala, "CM-SU"},
    {Tz::Africa_Douala, "CM-SW"},
    {Tz::Africa_El_Aaiun},
    {Tz::Africa_El_Aaiun, "EH"},
    {Tz::Africa_El_Aaiun, "MA-10"},
    {Tz::Africa_El_Aaiun, "MA-11"},
    {Tz::Africa_El_Aaiun, "MA-12"},
    {Tz::Africa_Freetown},
    {Tz::Africa_Freetown, "SL"},
    {Tz::Africa_Freetown, "SL-E"},
    {Tz::Africa_Freetown, "SL-N"},
    {Tz::Africa_Freetown, "SL-NW"},
    {Tz::Africa_Freetown, "SL-S"},
    {Tz::Africa_Freetown, "SL-W"},
    {Tz::Africa_Gaborone},
    {Tz::Africa_Gaborone, "BW"},
    {Tz::Africa_Gaborone, "BW-CE"},
    {Tz::Africa_Gaborone, "BW-CH"},
    {Tz::Africa_Gaborone, "BW-GH"},
    {Tz::Africa_Gaborone, "BW-KG"},
    {Tz::Africa_Gaborone, "BW-KL"},
    {Tz::Africa_Gaborone, "BW-KW"},
    {Tz::Africa_Gaborone, "BW-NE"},
    {Tz::Africa_Gaborone, "BW-NW"},
    {Tz::Africa_Gaborone, "BW-SE"},
    {Tz::Africa_Gaborone, "BW-SO"},
    {Tz::Africa_Harare},
    {Tz::Africa_Harare, "ZW"},
    {Tz::Africa_Harare, "ZW-BU"},
    {Tz::Africa_Harare, "ZW-HA"},
    {Tz::Africa_Harare, "ZW-MA"},
    {Tz::Africa_Harare, "ZW-MC"},
    {Tz::Africa_Harare, "ZW-ME"},
    {Tz::Africa_Harare, "ZW-MI"},
    {Tz::Africa_Harare, "ZW-MN"},
    {Tz::Africa_Harare, "ZW-MS"},
    {Tz::Africa_Harare, "ZW-MV"},
    {Tz::Africa_Harare, "ZW-MW"},
    {Tz::Africa_Johannesburg},
    {Tz::Africa_Johannesburg, "ZA"},
    {Tz::Africa_Johannesburg, "ZA-EC"},
    {Tz::Africa_Johannesburg, "ZA-FS"},
    {Tz::Africa_Johannesburg, "ZA-GP"},
    {Tz::Africa_Johannesburg, "ZA-KZN"},
    {Tz::Africa_Johannesburg, "ZA-LP"},
    {Tz::Africa_Johannesburg, "ZA-MP"},
    {Tz::Africa_Johannesburg, "ZA-NC"},
    {Tz::Africa_Johannesburg, "ZA-NW"},
    {Tz::Africa_Johannesburg, "ZA-WC"},
    {Tz::Africa_Juba},
    {Tz::Africa_Juba, "SS"},
    {Tz::Africa_Juba, "SS-BN"},
    {Tz::Africa_Juba, "SS-BW"},
    {Tz::Africa_Juba, "SS-EC"},
    {Tz::Africa_Juba, "SS-EE"},
    {Tz::Africa_Juba, "SS-EW"},
    {Tz::Africa_Juba, "SS-JG"},
    {Tz::Africa_Juba, "SS-LK"},
    {Tz::Africa_Juba, "SS-NU"},
    {Tz::Africa_Juba, "SS-UY"},
    {Tz::Africa_Juba, "SS-WR"},
    {Tz::Africa_Kampala},
    {Tz::Africa_Kampala, "UG"},
    {Tz::Africa_Kampala, "UG-C"},
    {Tz::Africa_Kampala, "UG-E"},
    {Tz::Africa_Kampala, "UG-N"},
    {Tz::Africa_Kampala, "UG-W"},
    {Tz::Africa_Khartoum},
    {Tz::Africa_Khartoum, "SD"},
    {Tz::Africa_Khartoum, "SD-DC"},
    {Tz::Africa_Khartoum, "SD-DE"},
    {Tz::Africa_Khartoum, "SD-DN"},
    {Tz::Africa_Khartoum, "SD-DS"},
    {Tz::Africa_Khartoum, "SD-DW"},
    {Tz::Africa_Khartoum, "SD-GD"},
    {Tz::Africa_Khartoum, "SD-GK"},
    {Tz::Africa_Khartoum, "SD-GZ"},
    {Tz::Africa_Khartoum, "SD-KA"},
    {Tz::Africa_Khartoum, "SD-KH"},
    {Tz::Africa_Khartoum, "SD-KN"},
    {Tz::Africa_Khartoum, "SD-KS"},
    {Tz::Africa_Khartoum, "SD-NB"},
    {Tz::Africa_Khartoum, "SD-NO"},
    {Tz::Africa_Khartoum, "SD-NR"},
    {Tz::Africa_Khartoum, "SD-NW"},
    {Tz::Africa_Khartoum, "SD-RS"},
    {Tz::Africa_Khartoum, "SD-SI"},
    {Tz::Africa_Khartoum, "SS-BW"},
    {Tz::Africa_Kigali},
    {Tz::Africa_Kigali, "RW"},
    {Tz::Africa_Kigali, "RW-01"},
    {Tz::Africa_Kigali, "RW-02"},
    {Tz::Africa_Kigali, "RW-03"},
    {Tz::Africa_Kigali, "RW-04"},
    {Tz::Africa_Kigali, "RW-05"},
    {Tz::Africa_Kinshasa},
    {Tz::Africa_Kinshasa, "CD"},
    {Tz::Africa_Kinshasa, "CD-BC"},
    {Tz::Africa_Kinshasa, "CD-EQ"},
    {Tz::Africa_Kinshasa, "CD-KG"},
    {Tz::Africa_Kinshasa, "CD-KL"},
    {Tz::Africa_Kinshasa, "CD-KN"},
    {Tz::Africa_Kinshasa, "CD-MN"},
    {Tz::Africa_Kinshasa, "CD-MO"},
    {Tz::Africa_Kinshasa, "CD-NU"},
    {Tz::Africa_Kinshasa, "CD-SU"},
    {Tz::Africa_Kinshasa, "CD-TU"},
    {Tz::Africa_Lagos},
    {Tz::Africa_Lagos, "NG"},
    {Tz::Africa_Lagos, "NG-AB"},
    {Tz::Africa_Lagos, "NG-AD"},
    {Tz::Africa_Lagos, "NG-AK"},
    {Tz::Africa_Lagos, "NG-AN"},
    {Tz::Africa_Lagos, "NG-BA"},
    {Tz::Africa_Lagos, "NG-BE"},
    {Tz::Africa_Lagos, "NG-BO"},
    {Tz::Africa_Lagos, "NG-BY"},
    {Tz::Africa_Lagos, "NG-CR"},
    {Tz::Africa_Lagos, "NG-DE"},
    {Tz::Africa_Lagos, "NG-EB"},
    {Tz::Africa_Lagos, "NG-ED"},
    {Tz::Africa_Lagos, "NG-EK"},
    {Tz::Africa_Lagos, "NG-EN"},
    {Tz::Africa_Lagos, "NG-FC"},
    {Tz::Africa_Lagos, "NG-GO"},
    {Tz::Africa_Lagos, "NG-IM"},
    {Tz::Africa_Lagos, "NG-JI"},
    {Tz::Africa_Lagos, "NG-KD"},
    {Tz::Africa_Lagos, "NG-KE"},
    {Tz::Africa_Lagos, "NG-KN"},
    {Tz::Africa_Lagos, "NG-KO"},
    {Tz::Africa_Lagos, "NG-KT"},
    {Tz::Africa_Lagos, "NG-KW"},
    {Tz::Africa_Lagos, "NG-LA"},
    {Tz::Africa_Lagos, "NG-NA"},
    {Tz::Africa_Lagos, "NG-NI"},
    {Tz::Africa_Lagos, "NG-OG"},
    {Tz::Africa_Lagos, "NG-ON"},
    {Tz::Africa_Lagos, "NG-OS"},
    {Tz::Africa_Lagos, "NG-OY"},
    {Tz::Africa_Lagos, "NG-PL"},
    {Tz::Africa_Lagos, "NG-RI"},
    {Tz::Africa_Lagos, "NG-SO"},
    {Tz::Africa_Lagos, "NG-TA"},
    {Tz::Africa_Lagos, "NG-YO"},
    {Tz::Africa_Lagos, "NG-ZA"},
    {Tz::Africa_Libreville},
    {Tz::Africa_Libreville, "GA"},
    {Tz::Africa_Libreville, "GA-1"},
    {Tz::Africa_Libreville, "GA-2"},
    {Tz::Africa_Libreville, "GA-3"},
    {Tz::Africa_Libreville, "GA-4"},
    {Tz::Africa_Libreville, "GA-5"},
    {Tz::Africa_Libreville, "GA-6"},
    {Tz::Africa_Libreville, "GA-7"},
    {Tz::Africa_Libreville, "GA-8"},
    {Tz::Africa_Libreville, "GA-9"},
    {Tz::Africa_Lome},
    {Tz::Africa_Lome, "TG"},
    {Tz::Africa_Lome, "TG-C"},
    {Tz::Africa_Lome, "TG-K"},
    {Tz::Africa_Lome, "TG-M"},
    {Tz::Africa_Lome, "TG-P"},
    {Tz::Africa_Lome, "TG-S"},
    {Tz::Africa_Luanda},
    {Tz::Africa_Luanda, "AO"},
    {Tz::Africa_Luanda, "AO-BGO"},
    {Tz::Africa_Luanda, "AO-BGU"},
    {Tz::Africa_Luanda, "AO-BIE"},
    {Tz::Africa_Luanda, "AO-CAB"},
    {Tz::Africa_Luanda, "AO-CCU"},
    {Tz::Africa_Luanda, "AO-CNN"},
    {Tz::Africa_Luanda, "AO-CNO"},
    {Tz::Africa_Luanda, "AO-CUS"},
    {Tz::Africa_Luanda, "AO-HUA"},
    {Tz::Africa_Luanda, "AO-HUI"},
    {Tz::Africa_Luanda, "AO-LNO"},
    {Tz::Africa_Luanda, "AO-LSU"},
    {Tz::Africa_Luanda, "AO-LUA"},
    {Tz::Africa_Luanda, "AO-MAL"},
    {Tz::Africa_Luanda, "AO-MOX"},
    {Tz::Africa_Luanda, "AO-NAM"},
    {Tz::Africa_Luanda, "AO-UIG"},
    {Tz::Africa_Luanda, "AO-ZAI"},
    {Tz::Africa_Lubumbashi},
    {Tz::Africa_Lubumbashi, "CD"},
    {Tz::Africa_Lubumbashi, "CD-BU"},
    {Tz::Africa_Lubumbashi, "CD-HK"},
    {Tz::Africa_Lubumbashi, "CD-HL"},
    {Tz::Africa_Lubumbashi, "CD-HU"},
    {Tz::Africa_Lubumbashi, "CD-IT"},
    {Tz::Africa_Lubumbashi, "CD-KC"},
    {Tz::Africa_Lubumbashi, "CD-KE"},
    {Tz::Africa_Lubumbashi, "CD-KS"},
    {Tz::Africa_Lubumbashi, "CD-LO"},
    {Tz::Africa_Lubumbashi, "CD-LU"},
    {Tz::Africa_Lubumbashi, "CD-MA"},
    {Tz::Africa_Lubumbashi, "CD-NK"},
    {Tz::Africa_Lubumbashi, "CD-SA"},
    {Tz::Africa_Lubumbashi, "CD-SK"},
    {Tz::Africa_Lubumbashi, "CD-TA"},
    {Tz::Africa_Lubumbashi, "CD-TO"},
    {Tz::Africa_Lusaka},
    {Tz::Africa_Lusaka, "ZM"},
    {Tz::Africa_Lusaka, "ZM-01"},
    {Tz::Africa_Lusaka, "ZM-02"},
    {Tz::Africa_Lusaka, "ZM-03"},
    {Tz::Africa_Lusaka, "ZM-04"},
    {Tz::Africa_Lusaka, "ZM-05"},
    {Tz::Africa_Lusaka, "ZM-06"},
    {Tz::Africa_Lusaka, "ZM-07"},
    {Tz::Africa_Lusaka, "ZM-08"},
    {Tz::Africa_Lusaka, "ZM-09"},
    {Tz::Africa_Lusaka, "ZM-10"},
    {Tz::Africa_Malabo},
    {Tz::Africa_Malabo, "GQ"},
    {Tz::Africa_Malabo, "GQ-C"},
    {Tz::Africa_Malabo, "GQ-I"},
    {Tz::Africa_Maputo},
    {Tz::Africa_Maputo, "MZ"},
    {Tz::Africa_Maputo, "MZ-A"},
    {Tz::Africa_Maputo, "MZ-B"},
    {Tz::Africa_Maputo, "MZ-G"},
    {Tz::Africa_Maputo, "MZ-I"},
    {Tz::Africa_Maputo, "MZ-L"},
    {Tz::Africa_Maputo, "MZ-MPM"},
    {Tz::Africa_Maputo, "MZ-N"},
    {Tz::Africa_Maputo, "MZ-P"},
    {Tz::Africa_Maputo, "MZ-Q"},
    {Tz::Africa_Maputo, "MZ-S"},
    {Tz::Africa_Maputo, "MZ-T"},
    {Tz::Africa_Maseru},
    {Tz::Africa_Maseru, "LS"},
    {Tz::Africa_Maseru, "LS-A"},
    {Tz::Africa_Maseru, "LS-B"},
    {Tz::Africa_Maseru, "LS-C"},
    {Tz::Africa_Maseru, "LS-D"},
    {Tz::Africa_Maseru, "LS-E"},
    {Tz::Africa_Maseru, "LS-F"},
    {Tz::Africa_Maseru, "LS-G"},
    {Tz::Africa_Maseru, "LS-H"},
    {Tz::Africa_Maseru, "LS-J"},
    {Tz::Africa_Maseru, "LS-K"},
    {Tz::Africa_Mbabane},
    {Tz::Africa_Mbabane, "SZ"},
    {Tz::Africa_Mbabane, "SZ-HH"},
    {Tz::Africa_Mbabane, "SZ-LU"},
    {Tz::Africa_Mbabane, "SZ-MA"},
    {Tz::Africa_Mbabane, "SZ-SH"},
    {Tz::Africa_Mogadishu},
    {Tz::Africa_Mogadishu, "SO"},
    {Tz::Africa_Mogadishu, "SO-AW"},
    {Tz::Africa_Mogadishu, "SO-BK"},
    {Tz::Africa_Mogadishu, "SO-BN"},
    {Tz::Africa_Mogadishu, "SO-BR"},
    {Tz::Africa_Mogadishu, "SO-BY"},
    {Tz::Africa_Mogadishu, "SO-GA"},
    {Tz::Africa_Mogadishu, "SO-GE"},
    {Tz::Africa_Mogadishu, "SO-HI"},
    {Tz::Africa_Mogadishu, "SO-JD"},
    {Tz::Africa_Mogadishu, "SO-JH"},
    {Tz::Africa_Mogadishu, "SO-MU"},
    {Tz::Africa_Mogadishu, "SO-NU"},
    {Tz::Africa_Mogadishu, "SO-SA"},
    {Tz::Africa_Mogadishu, "SO-SD"},
    {Tz::Africa_Mogadishu, "SO-SH"},
    {Tz::Africa_Mogadishu, "SO-SO"},
    {Tz::Africa_Mogadishu, "SO-TO"},
    {Tz::Africa_Mogadishu, "SO-WO"},
    {Tz::Africa_Monrovia},
    {Tz::Africa_Monrovia, "LR"},
    {Tz::Africa_Monrovia, "LR-BG"},
    {Tz::Africa_Monrovia, "LR-BM"},
    {Tz::Africa_Monrovia, "LR-CM"},
    {Tz::Africa_Monrovia, "LR-GB"},
    {Tz::Africa_Monrovia, "LR-GG"},
    {Tz::Africa_Monrovia, "LR-GK"},
    {Tz::Africa_Monrovia, "LR-GP"},
    {Tz::Africa_Monrovia, "LR-LO"},
    {Tz::Africa_Monrovia, "LR-MG"},
    {Tz::Africa_Monrovia, "LR-MO"},
    {Tz::Africa_Monrovia, "LR-MY"},
    {Tz::Africa_Monrovia, "LR-NI"},
    {Tz::Africa_Monrovia, "LR-RG"},
    {Tz::Africa_Monrovia, "LR-RI"},
    {Tz::Africa_Monrovia, "LR-SI"},
    {Tz::Africa_Nairobi},
    {Tz::Africa_Nairobi, "KE"},
    {Tz::Africa_Nairobi, "KE-01"},
    {Tz::Africa_Nairobi, "KE-02"},
    {Tz::Africa_Nairobi, "KE-03"},
    {Tz::Africa_Nairobi, "KE-04"},
    {Tz::Africa_Nairobi, "KE-05"},
    {Tz::Africa_Nairobi, "KE-06"},
    {Tz::Africa_Nairobi, "KE-07"},
    {Tz::Africa_Nairobi, "KE-08"},
    {Tz::Africa_Nairobi, "KE-09"},
    {Tz::Africa_Nairobi, "KE-10"},
    {Tz::Africa_Nairobi, "KE-11"},
    {Tz::Africa_Nairobi, "KE-12"},
    {Tz::Africa_Nairobi, "KE-13"},
    {Tz::Africa_Nairobi, "KE-14"},
    {Tz::Africa_Nairobi, "KE-15"},
    {Tz::Africa_Nairobi, "KE-17"},
    {Tz::Africa_Nairobi, "KE-18"},
    {Tz::Africa_Nairobi, "KE-19"},
    {Tz::Africa_Nairobi, "KE-20"},
    {Tz::Africa_Nairobi, "KE-21"},
    {Tz::Africa_Nairobi, "KE-22"},
    {Tz::Africa_Nairobi, "KE-23"},
    {Tz::Africa_Nairobi, "KE-24"},
    {Tz::Africa_Nairobi, "KE-25"},
    {Tz::Africa_Nairobi, "KE-26"},
    {Tz::Africa_Nairobi, "KE-27"},
    {Tz::Africa_Nairobi, "KE-28"},
    {Tz::Africa_Nairobi, "KE-29"},
    {Tz::Africa_Nairobi, "KE-30"},
    {Tz::Africa_Nairobi, "KE-31"},
    {Tz::Africa_Nairobi, "KE-32"},
    {Tz::Africa_Nairobi, "KE-33"},
    {Tz::Africa_Nairobi, "KE-35"},
    {Tz::Africa_Nairobi, "KE-36"},
    {Tz::Africa_Nairobi, "KE-37"},
    {Tz::Africa_Nairobi, "KE-38"},
    {Tz::Africa_Nairobi, "KE-39"},
    {Tz::Africa_Nairobi, "KE-40"},
    {Tz::Africa_Nairobi, "KE-41"},
    {Tz::Africa_Nairobi, "KE-42"},
    {Tz::Africa_Nairobi, "KE-43"},
    {Tz::Africa_Nairobi, "KE-44"},
    {Tz::Africa_Nairobi, "KE-45"},
    {Tz::Africa_Nairobi, "KE-46"},
    {Tz::Africa_Nairobi, "KE-47"},
    {Tz::Africa_Ndjamena},
    {Tz::Africa_Ndjamena, "TD"},
    {Tz::Africa_Ndjamena, "TD-BA"},
    {Tz::Africa_Ndjamena, "TD-BG"},
    {Tz::Africa_Ndjamena, "TD-BO"},
    {Tz::Africa_Ndjamena, "TD-CB"},
    {Tz::Africa_Ndjamena, "TD-EE"},
    {Tz::Africa_Ndjamena, "TD-EO"},
    {Tz::Africa_Ndjamena, "TD-GR"},
    {Tz::Africa_Ndjamena, "TD-HL"},
    {Tz::Africa_Ndjamena, "TD-KA"},
    {Tz::Africa_Ndjamena, "TD-LC"},
    {Tz::Africa_Ndjamena, "TD-LO"},
    {Tz::Africa_Ndjamena, "TD-LR"},
    {Tz::Africa_Ndjamena, "TD-MA"},
    {Tz::Africa_Ndjamena, "TD-MC"},
    {Tz::Africa_Ndjamena, "TD-ME"},
    {Tz::Africa_Ndjamena, "TD-MO"},
    {Tz::Africa_Ndjamena, "TD-ND"},
    {Tz::Africa_Ndjamena, "TD-OD"},
    {Tz::Africa_Ndjamena, "TD-SA"},
    {Tz::Africa_Ndjamena, "TD-SI"},
    {Tz::Africa_Ndjamena, "TD-TA"},
    {Tz::Africa_Ndjamena, "TD-TI"},
    {Tz::Africa_Ndjamena, "TD-WF"},
    {Tz::Africa_Niamey},
    {Tz::Africa_Niamey, "NE"},
    {Tz::Africa_Niamey, "NE-1"},
    {Tz::Africa_Niamey, "NE-2"},
    {Tz::Africa_Niamey, "NE-3"},
    {Tz::Africa_Niamey, "NE-4"},
    {Tz::Africa_Niamey, "NE-5"},
    {Tz::Africa_Niamey, "NE-6"},
    {Tz::Africa_Niamey, "NE-7"},
    {Tz::Africa_Nouakchott},
    {Tz::Africa_Nouakchott, "MR"},
    {Tz::Africa_Nouakchott, "MR-01"},
    {Tz::Africa_Nouakchott, "MR-02"},
    {Tz::Africa_Nouakchott, "MR-03"},
    {Tz::Africa_Nouakchott, "MR-04"},
    {Tz::Africa_Nouakchott, "MR-05"},
    {Tz::Africa_Nouakchott, "MR-06"},
    {Tz::Africa_Nouakchott, "MR-07"},
    {Tz::Africa_Nouakchott, "MR-08"},
    {Tz::Africa_Nouakchott, "MR-09"},
    {Tz::Africa_Nouakchott, "MR-10"},
    {Tz::Africa_Nouakchott, "MR-11"},
    {Tz::Africa_Nouakchott, "MR-12"},
    {Tz::Africa_Nouakchott, "MR-NKC"},
    {Tz::Africa_Ouagadougou},
    {Tz::Africa_Ouagadougou, "BF"},
    {Tz::Africa_Ouagadougou, "BF-01"},
    {Tz::Africa_Ouagadougou, "BF-02"},
    {Tz::Africa_Ouagadougou, "BF-03"},
    {Tz::Africa_Ouagadougou, "BF-04"},
    {Tz::Africa_Ouagadougou, "BF-05"},
    {Tz::Africa_Ouagadougou, "BF-06"},
    {Tz::Africa_Ouagadougou, "BF-07"},
    {Tz::Africa_Ouagadougou, "BF-08"},
    {Tz::Africa_Ouagadougou, "BF-09"},
    {Tz::Africa_Ouagadougou, "BF-10"},
    {Tz::Africa_Ouagadougou, "BF-11"},
    {Tz::Africa_Ouagadougou, "BF-12"},
    {Tz::Africa_Ouagadougou, "BF-13"},
    {Tz::Africa_Porto_Novo},
    {Tz::Africa_Porto_Novo, "BJ"},
    {Tz::Africa_Porto_Novo, "BJ-AK"},
    {Tz::Africa_Porto_Novo, "BJ-AL"},
    {Tz::Africa_Porto_Novo, "BJ-AQ"},
    {Tz::Africa_Porto_Novo, "BJ-BO"},
    {Tz::Africa_Porto_Novo, "BJ-CO"},
    {Tz::Africa_Porto_Novo, "BJ-DO"},
    {Tz::Africa_Porto_Novo, "BJ-KO"},
    {Tz::Africa_Porto_Novo, "BJ-MO"},
    {Tz::Africa_Porto_Novo, "BJ-OU"},
    {Tz::Africa_Porto_Novo, "BJ-PL"},
    {Tz::Africa_Porto_Novo, "BJ-ZO"},
    {Tz::Africa_Sao_Tome, "ST"},
    {Tz::Africa_Sao_Tome, "ST-P"},
    {Tz::Africa_Sao_Tome, "ST-S"},
    {Tz::Africa_Tripoli},
    {Tz::Africa_Tripoli, "LY"},
    {Tz::Africa_Tripoli, "LY-BA"},
    {Tz::Africa_Tripoli, "LY-BU"},
    {Tz::Africa_Tripoli, "LY-DR"},
    {Tz::Africa_Tripoli, "LY-GT"},
    {Tz::Africa_Tripoli, "LY-JA"},
    {Tz::Africa_Tripoli, "LY-JG"},
    {Tz::Africa_Tripoli, "LY-JI"},
    {Tz::Africa_Tripoli, "LY-JU"},
    {Tz::Africa_Tripoli, "LY-KF"},
    {Tz::Africa_Tripoli, "LY-MB"},
    {Tz::Africa_Tripoli, "LY-MI"},
    {Tz::Africa_Tripoli, "LY-MJ"},
    {Tz::Africa_Tripoli, "LY-MQ"},
    {Tz::Africa_Tripoli, "LY-NL"},
    {Tz::Africa_Tripoli, "LY-NQ"},
    {Tz::Africa_Tripoli, "LY-SB"},
    {Tz::Africa_Tripoli, "LY-SR"},
    {Tz::Africa_Tripoli, "LY-TB"},
    {Tz::Africa_Tripoli, "LY-WA"},
    {Tz::Africa_Tripoli, "LY-WD"},
    {Tz::Africa_Tripoli, "LY-WS"},
    {Tz::Africa_Tripoli, "LY-ZA"},
    {Tz::Africa_Tunis},
    {Tz::Africa_Tunis, "TN"},
    {Tz::Africa_Tunis, "TN-12"},
    {Tz::Africa_Tunis, "TN-13"},
    {Tz::Africa_Tunis, "TN-14"},
    {Tz::Africa_Tunis, "TN-21"},
    {Tz::Africa_Tunis, "TN-22"},
    {Tz::Africa_Tunis, "TN-23"},
    {Tz::Africa_Tunis, "TN-31"},
    {Tz::Africa_Tunis, "TN-32"},
    {Tz::Africa_Tunis, "TN-33"},
    {Tz::Africa_Tunis, "TN-34"},
    {Tz::Africa_Tunis, "TN-41"},
    {Tz::Africa_Tunis, "TN-42"},
    {Tz::Africa_Tunis, "TN-43"},
    {Tz::Africa_Tunis, "TN-51"},
    {Tz::Africa_Tunis, "TN-52"},
    {Tz::Africa_Tunis, "TN-53"},
    {Tz::Africa_Tunis, "TN-61"},
    {Tz::Africa_Tunis, "TN-71"},
    {Tz::Africa_Tunis, "TN-72"},
    {Tz::Africa_Tunis, "TN-73"},
    {Tz::Africa_Tunis, "TN-81"},
    {Tz::Africa_Tunis, "TN-82"},
    {Tz::Africa_Tunis, "TN-83"},
    {Tz::Africa_Windhoek},
    {Tz::Africa_Windhoek, "NA"},
    {Tz::Africa_Windhoek, "NA-CA"},
    {Tz::Africa_Windhoek, "NA-ER"},
    {Tz::Africa_Windhoek, "NA-HA"},
    {Tz::Africa_Windhoek, "NA-KA"},
    {Tz::Africa_Windhoek, "NA-KE"},
    {Tz::Africa_Windhoek, "NA-KH"},
    {Tz::Africa_Windhoek, "NA-KU"},
    {Tz::Africa_Windhoek, "NA-KW"},
    {Tz::Africa_Windhoek, "NA-OD"},
    {Tz::Africa_Windhoek, "NA-OH"},
    {Tz::Africa_Windhoek, "NA-ON"},
    {Tz::Africa_Windhoek, "NA-OS"},
    {Tz::Africa_Windhoek, "NA-OT"},
    {Tz::Africa_Windhoek, "NA-OW"},
    {Tz::America_Adak, "US-AK"},
    {Tz::America_Anchorage, "US-AK"},
    {Tz::America_Anguilla, "AI"},
    {Tz::America_Antigua},
    {Tz::America_Antigua, "AG"},
    {Tz::America_Antigua, "AG-04"},
    {Tz::America_Antigua, "AG-05"},
    {Tz::America_Antigua, "AG-08"},
    {Tz::America_Antigua, "AG-10"},
    {Tz::America_Antigua, "AG-11"},
    {Tz::America_Araguaina, "BR"},
    {Tz::America_Araguaina, "BR-TO"},
    {Tz::America_Argentina_Buenos_Aires},
    {Tz::America_Argentina_Buenos_Aires, "AR"},
    {Tz::America_Argentina_Buenos_Aires, "AR-A"},
    {Tz::America_Argentina_Buenos_Aires, "AR-B"},
    {Tz::America_Argentina_Buenos_Aires, "AR-D"},
    {Tz::America_Argentina_Buenos_Aires, "AR-E"},
    {Tz::America_Argentina_Buenos_Aires, "AR-F"},
    {Tz::America_Argentina_Buenos_Aires, "AR-G"},
    {Tz::America_Argentina_Buenos_Aires, "AR-H"},
    {Tz::America_Argentina_Buenos_Aires, "AR-J"},
    {Tz::America_Argentina_Buenos_Aires, "AR-K"},
    {Tz::America_Argentina_Buenos_Aires, "AR-L"},
    {Tz::America_Argentina_Buenos_Aires, "AR-M"},
    {Tz::America_Argentina_Buenos_Aires, "AR-N"},
    {Tz::America_Argentina_Buenos_Aires, "AR-P"},
    {Tz::America_Argentina_Buenos_Aires, "AR-Q"},
    {Tz::America_Argentina_Buenos_Aires, "AR-R"},
    {Tz::America_Argentina_Buenos_Aires, "AR-S"},
    {Tz::America_Argentina_Buenos_Aires, "AR-T"},
    {Tz::America_Argentina_Buenos_Aires, "AR-U"},
    {Tz::America_Argentina_Buenos_Aires, "AR-V"},
    {Tz::America_Argentina_Buenos_Aires, "AR-W"},
    {Tz::America_Argentina_Buenos_Aires, "AR-X"},
    {Tz::America_Argentina_Buenos_Aires, "AR-Y"},
    {Tz::America_Argentina_Buenos_Aires, "AR-Z"},
    {Tz::America_Aruba, "AW"},
    {Tz::America_Aruba, "NL-AW"},
    {Tz::America_Asuncion, "PY"},
    {Tz::America_Asuncion, "PY-1"},
    {Tz::America_Asuncion, "PY-10"},
    {Tz::America_Asuncion, "PY-11"},
    {Tz::America_Asuncion, "PY-12"},
    {Tz::America_Asuncion, "PY-13"},
    {Tz::America_Asuncion, "PY-14"},
    {Tz::America_Asuncion, "PY-15"},
    {Tz::America_Asuncion, "PY-16"},
    {Tz::America_Asuncion, "PY-19"},
    {Tz::America_Asuncion, "PY-2"},
    {Tz::America_Asuncion, "PY-3"},
    {Tz::America_Asuncion, "PY-4"},
    {Tz::America_Asuncion, "PY-5"},
    {Tz::America_Asuncion, "PY-6"},
    {Tz::America_Asuncion, "PY-7"},
    {Tz::America_Asuncion, "PY-8"},
    {Tz::America_Asuncion, "PY-9"},
    {Tz::America_Atikokan, "CA-NU"},
    {Tz::America_Atikokan, "CA-ON"},
    {Tz::America_Bahia, "BR"},
    {Tz::America_Bahia, "BR-BA"},
    {Tz::America_Bahia_Banderas, "MX"},
    {Tz::America_Bahia_Banderas, "MX-NAY"},
    {Tz::America_Barbados, "BB"},
    {Tz::America_Barbados, "BB-01"},
    {Tz::America_Belem},
    {Tz::America_Belem, "BR"},
    {Tz::America_Belem, "BR-AP"},
    {Tz::America_Belem, "BR-PA"},
    {Tz::America_Belize},
    {Tz::America_Belize, "BZ"},
    {Tz::America_Belize, "BZ-BZ"},
    {Tz::America_Belize, "BZ-CY"},
    {Tz::America_Belize, "BZ-CZL"},
    {Tz::America_Belize, "BZ-OW"},
    {Tz::America_Belize, "BZ-SC"},
    {Tz::America_Belize, "BZ-TOL"},
    {Tz::America_Blanc_Sablon, "CA-QC"},
    {Tz::America_Boa_Vista},
    {Tz::America_Boa_Vista, "BR"},
    {Tz::America_Boa_Vista, "BR-RR"},
    {Tz::America_Bogota},
    {Tz::America_Bogota, "CO"},
    {Tz::America_Bogota, "CO-AMA"},
    {Tz::America_Bogota, "CO-ANT"},
    {Tz::America_Bogota, "CO-ARA"},
    {Tz::America_Bogota, "CO-ATL"},
    {Tz::America_Bogota, "CO-BOL"},
    {Tz::America_Bogota, "CO-BOY"},
    {Tz::America_Bogota, "CO-CAL"},
    {Tz::America_Bogota, "CO-CAQ"},
    {Tz::America_Bogota, "CO-CAS"},
    {Tz::America_Bogota, "CO-CAU"},
    {Tz::America_Bogota, "CO-CES"},
    {Tz::America_Bogota, "CO-CHO"},
    {Tz::America_Bogota, "CO-COR"},
    {Tz::America_Bogota, "CO-CUN"},
    {Tz::America_Bogota, "CO-GUA"},
    {Tz::America_Bogota, "CO-GUV"},
    {Tz::America_Bogota, "CO-HUI"},
    {Tz::America_Bogota, "CO-LAG"},
    {Tz::America_Bogota, "CO-MAG"},
    {Tz::America_Bogota, "CO-MET"},
    {Tz::America_Bogota, "CO-NAR"},
    {Tz::America_Bogota, "CO-NSA"},
    {Tz::America_Bogota, "CO-PUT"},
    {Tz::America_Bogota, "CO-QUI"},
    {Tz::America_Bogota, "CO-RIS"},
    {Tz::America_Bogota, "CO-SAN"},
    {Tz::America_Bogota, "CO-SAP"},
    {Tz::America_Bogota, "CO-SUC"},
    {Tz::America_Bogota, "CO-TOL"},
    {Tz::America_Bogota, "CO-VAC"},
    {Tz::America_Bogota, "CO-VAU"},
    {Tz::America_Bogota, "CO-VID"},
    {Tz::America_Boise, "US"},
    {Tz::America_Boise, "US-ID"},
    {Tz::America_Boise, "US-OR"},
    {Tz::America_Cambridge_Bay, "CA"},
    {Tz::America_Cambridge_Bay, "CA-NT"},
    {Tz::America_Cambridge_Bay, "CA-NU"},
    {Tz::America_Campo_Grande},
    {Tz::America_Campo_Grande, "BR"},
    {Tz::America_Campo_Grande, "BR-MS"},
    {Tz::America_Cancun},
    {Tz::America_Cancun, "MX"},
    {Tz::America_Cancun, "MX-ROO"},
    {Tz::America_Caracas},
    {Tz::America_Caracas, "VE"},
    {Tz::America_Caracas, "VE-B"},
    {Tz::America_Caracas, "VE-C"},
    {Tz::America_Caracas, "VE-D"},
    {Tz::America_Caracas, "VE-E"},
    {Tz::America_Caracas, "VE-F"},
    {Tz::America_Caracas, "VE-G"},
    {Tz::America_Caracas, "VE-H"},
    {Tz::America_Caracas, "VE-I"},
    {Tz::America_Caracas, "VE-J"},
    {Tz::America_Caracas, "VE-K"},
    {Tz::America_Caracas, "VE-L"},
    {Tz::America_Caracas, "VE-M"},
    {Tz::America_Caracas, "VE-N"},
    {Tz::America_Caracas, "VE-O"},
    {Tz::America_Caracas, "VE-P"},
    {Tz::America_Caracas, "VE-R"},
    {Tz::America_Caracas, "VE-S"},
    {Tz::America_Caracas, "VE-T"},
    {Tz::America_Caracas, "VE-U"},
    {Tz::America_Caracas, "VE-V"},
    {Tz::America_Caracas, "VE-W"},
    {Tz::America_Caracas, "VE-X"},
    {Tz::America_Caracas, "VE-Y"},
    {Tz::America_Caracas, "VE-Z"},
    {Tz::America_Cayenne},
    {Tz::America_Cayenne, "GF"},
    {Tz::America_Cayman, "KY"},
    {Tz::America_Chicago},
    {Tz::America_Chicago, "US"},
    {Tz::America_Chicago, "US-AL"},
    {Tz::America_Chicago, "US-AR"},
    {Tz::America_Chicago, "US-FL"},
    {Tz::America_Chicago, "US-IA"},
    {Tz::America_Chicago, "US-IL"},
    {Tz::America_Chicago, "US-IN"},
    {Tz::America_Chicago, "US-KS"},
    {Tz::America_Chicago, "US-KY"},
    {Tz::America_Chicago, "US-LA"},
    {Tz::America_Chicago, "US-MN"},
    {Tz::America_Chicago, "US-MO"},
    {Tz::America_Chicago, "US-MS"},
    {Tz::America_Chicago, "US-ND"},
    {Tz::America_Chicago, "US-NE"},
    {Tz::America_Chicago, "US-OK"},
    {Tz::America_Chicago, "US-SD"},
    {Tz::America_Chicago, "US-TN"},
    {Tz::America_Chicago, "US-TX"},
    {Tz::America_Chicago, "US-WI"},
    {Tz::America_Chihuahua, "MX"},
    {Tz::America_Chihuahua, "MX-CHH"},
    {Tz::America_Costa_Rica},
    {Tz::America_Costa_Rica, "CR"},
    {Tz::America_Costa_Rica, "CR-A"},
    {Tz::America_Costa_Rica, "CR-C"},
    {Tz::America_Costa_Rica, "CR-G"},
    {Tz::America_Costa_Rica, "CR-H"},
    {Tz::America_Costa_Rica, "CR-L"},
    {Tz::America_Costa_Rica, "CR-P"},
    {Tz::America_Costa_Rica, "CR-SJ"},
    {Tz::America_Creston, "CA-BC"},
    {Tz::America_Cuiaba},
    {Tz::America_Cuiaba, "BR"},
    {Tz::America_Cuiaba, "BR-MT"},
    {Tz::America_Curacao},
    {Tz::America_Curacao, "CW"},
    {Tz::America_Curacao, "NL-CW"},
    {Tz::America_Danmarkshavn, "GL"},
    {Tz::America_Dawson, "CA-YT"},
    {Tz::America_Dawson_Creek, "CA-BC"},
    {Tz::America_Denver},
    {Tz::America_Denver, "US"},
    {Tz::America_Denver, "US-AZ"},
    {Tz::America_Denver, "US-CO"},
    {Tz::America_Denver, "US-MT"},
    {Tz::America_Denver, "US-ND"},
    {Tz::America_Denver, "US-NE"},
    {Tz::America_Denver, "US-NM"},
    {Tz::America_Denver, "US-SD"},
    {Tz::America_Denver, "US-UT"},
    {Tz::America_Denver, "US-WY"},
    {Tz::America_Detroit},
    {Tz::America_Detroit, "US"},
    {Tz::America_Detroit, "US-MI"},
    {Tz::America_Dominica},
    {Tz::America_Dominica, "DM"},
    {Tz::America_Dominica, "DM-02"},
    {Tz::America_Dominica, "DM-06"},
    {Tz::America_Edmonton},
    {Tz::America_Edmonton, "CA"},
    {Tz::America_Edmonton, "CA-AB"},
    {Tz::America_Edmonton, "CA-BC"},
    {Tz::America_Edmonton, "CA-SK"},
    {Tz::America_Eirunepe},
    {Tz::America_Eirunepe, "BR"},
    {Tz::America_Eirunepe, "BR-AM"},
    {Tz::America_El_Salvador},
    {Tz::America_El_Salvador, "SV"},
    {Tz::America_El_Salvador, "SV-AH"},
    {Tz::America_El_Salvador, "SV-CA"},
    {Tz::America_El_Salvador, "SV-CH"},
    {Tz::America_El_Salvador, "SV-LI"},
    {Tz::America_El_Salvador, "SV-MO"},
    {Tz::America_El_Salvador, "SV-PA"},
    {Tz::America_El_Salvador, "SV-SA"},
    {Tz::America_El_Salvador, "SV-SM"},
    {Tz::America_El_Salvador, "SV-SO"},
    {Tz::America_El_Salvador, "SV-SV"},
    {Tz::America_El_Salvador, "SV-UN"},
    {Tz::America_El_Salvador, "SV-US"},
    {Tz::America_Fort_Nelson, "CA-BC"},
    {Tz::America_Fortaleza, "BR"},
    {Tz::America_Fortaleza, "BR-MA"},
    {Tz::America_Fortaleza, "BR-PB"},
    {Tz::America_Fortaleza, "BR-PE"},
    {Tz::America_Fortaleza, "BR-PI"},
    {Tz::America_Fortaleza, "BR-RN"},
    {Tz::America_Glace_Bay, "CA"},
    {Tz::America_Glace_Bay, "CA-NS"},
    {Tz::America_Goose_Bay, "CA-NL"},
    {Tz::America_Grand_Turk},
    {Tz::America_Grand_Turk, "TC"},
    {Tz::America_Grenada},
    {Tz::America_Grenada, "GD"},
    {Tz::America_Grenada, "GD-02"},
    {Tz::America_Grenada, "GD-05"},
    {Tz::America_Grenada, "GD-06"},
    {Tz::America_Grenada, "GD-10"},
    {Tz::America_Guadeloupe},
    {Tz::America_Guadeloupe, "GP"},
    {Tz::America_Guatemala},
    {Tz::America_Guatemala, "GT"},
    {Tz::America_Guatemala, "GT-AV"},
    {Tz::America_Guatemala, "GT-BV"},
    {Tz::America_Guatemala, "GT-CM"},
    {Tz::America_Guatemala, "GT-CQ"},
    {Tz::America_Guatemala, "GT-ES"},
    {Tz::America_Guatemala, "GT-GU"},
    {Tz::America_Guatemala, "GT-HU"},
    {Tz::America_Guatemala, "GT-IZ"},
    {Tz::America_Guatemala, "GT-JA"},
    {Tz::America_Guatemala, "GT-JU"},
    {Tz::America_Guatemala, "GT-PE"},
    {Tz::America_Guatemala, "GT-PR"},
    {Tz::America_Guatemala, "GT-QC"},
    {Tz::America_Guatemala, "GT-QZ"},
    {Tz::America_Guatemala, "GT-RE"},
    {Tz::America_Guatemala, "GT-SM"},
    {Tz::America_Guatemala, "GT-SO"},
    {Tz::America_Guatemala, "GT-SR"},
    {Tz::America_Guatemala, "GT-SU"},
    {Tz::America_Guatemala, "GT-ZA"},
    {Tz::America_Guayaquil},
    {Tz::America_Guayaquil, "EC"},
    {Tz::America_Guayaquil, "EC-A"},
    {Tz::America_Guayaquil, "EC-B"},
    {Tz::America_Guayaquil, "EC-C"},
    {Tz::America_Guayaquil, "EC-D"},
    {Tz::America_Guayaquil, "EC-E"},
    {Tz::America_Guayaquil, "EC-F"},
    {Tz::America_Guayaquil, "EC-G"},
    {Tz::America_Guayaquil, "EC-H"},
    {Tz::America_Guayaquil, "EC-I"},
    {Tz::America_Guayaquil, "EC-L"},
    {Tz::America_Guayaquil, "EC-M"},
    {Tz::America_Guayaquil, "EC-N"},
    {Tz::America_Guayaquil, "EC-O"},
    {Tz::America_Guayaquil, "EC-P"},
    {Tz::America_Guayaquil, "EC-R"},
    {Tz::America_Guayaquil, "EC-S"},
    {Tz::America_Guayaquil, "EC-SD"},
    {Tz::America_Guayaquil, "EC-SE"},
    {Tz::America_Guayaquil, "EC-T"},
    {Tz::America_Guayaquil, "EC-U"},
    {Tz::America_Guayaquil, "EC-X"},
    {Tz::America_Guayaquil, "EC-Y"},
    {Tz::America_Guayaquil, "EC-Z"},
    {Tz::America_Guyana},
    {Tz::America_Guyana, "GY"},
    {Tz::America_Guyana, "GY-BA"},
    {Tz::America_Guyana, "GY-CU"},
    {Tz::America_Guyana, "GY-DE"},
    {Tz::America_Guyana, "GY-EB"},
    {Tz::America_Guyana, "GY-ES"},
    {Tz::America_Guyana, "GY-MA"},
    {Tz::America_Guyana, "GY-PM"},
    {Tz::America_Guyana, "GY-PT"},
    {Tz::America_Guyana, "GY-UD"},
    {Tz::America_Guyana, "GY-UT"},
    {Tz::America_Halifax, "CA"},
    {Tz::America_Halifax, "CA-NS"},
    {Tz::America_Halifax, "CA-PE"},
    {Tz::America_Halifax, "CA-QC"},
    {Tz::America_Havana, "CU"},
    {Tz::America_Havana, "CU-01"},
    {Tz::America_Havana, "CU-03"},
    {Tz::America_Havana, "CU-04"},
    {Tz::America_Havana, "CU-05"},
    {Tz::America_Havana, "CU-06"},
    {Tz::America_Havana, "CU-07"},
    {Tz::America_Havana, "CU-08"},
    {Tz::America_Havana, "CU-09"},
    {Tz::America_Havana, "CU-10"},
    {Tz::America_Havana, "CU-11"},
    {Tz::America_Havana, "CU-12"},
    {Tz::America_Havana, "CU-13"},
    {Tz::America_Havana, "CU-14"},
    {Tz::America_Havana, "CU-15"},
    {Tz::America_Havana, "CU-16"},
    {Tz::America_Havana, "CU-99"},
    {Tz::America_Hermosillo},
    {Tz::America_Hermosillo, "MX"},
    {Tz::America_Hermosillo, "MX-SON"},
    {Tz::America_Indiana_Indianapolis, "US"},
    {Tz::America_Indiana_Indianapolis, "US-IN"},
    {Tz::America_Indiana_Knox, "US-IN"},
    {Tz::America_Indiana_Marengo, "US-IN"},
    {Tz::America_Indiana_Petersburg, "US-IN"},
    {Tz::America_Indiana_Tell_City, "US"},
    {Tz::America_Indiana_Tell_City, "US-IN"},
    {Tz::America_Indiana_Vevay, "US"},
    {Tz::America_Indiana_Vevay, "US-IN"},
    {Tz::America_Indiana_Vincennes, "US-IN"},
    {Tz::America_Indiana_Winamac, "US-IN"},
    {Tz::America_Inuvik, "CA"},
    {Tz::America_Inuvik, "CA-NT"},
    {Tz::America_Iqaluit, "CA"},
    {Tz::America_Iqaluit, "CA-NU"},
    {Tz::America_Iqaluit, "CA-QC"},
    {Tz::America_Jamaica, "JM"},
    {Tz::America_Jamaica, "JM-02"},
    {Tz::America_Jamaica, "JM-03"},
    {Tz::America_Jamaica, "JM-04"},
    {Tz::America_Jamaica, "JM-05"},
    {Tz::America_Jamaica, "JM-06"},
    {Tz::America_Jamaica, "JM-07"},
    {Tz::America_Jamaica, "JM-08"},
    {Tz::America_Jamaica, "JM-09"},
    {Tz::America_Jamaica, "JM-10"},
    {Tz::America_Jamaica, "JM-11"},
    {Tz::America_Jamaica, "JM-13"},
    {Tz::America_Jamaica, "JM-14"},
    {Tz::America_Juneau, "US-AK"},
    {Tz::America_Kentucky_Louisville, "US"},
    {Tz::America_Kentucky_Louisville, "US-IN"},
    {Tz::America_Kentucky_Louisville, "US-KY"},
    {Tz::America_Kentucky_Monticello, "US-KY"},
    {Tz::America_Kralendijk},
    {Tz::America_Kralendijk, "BQ"},
    {Tz::America_Kralendijk, "BQ-BO"},
    {Tz::America_Kralendijk, "BQ-SA"},
    {Tz::America_Kralendijk, "BQ-SE"},
    {Tz::America_La_Paz},
    {Tz::America_La_Paz, "BO"},
    {Tz::America_La_Paz, "BO-B"},
    {Tz::America_La_Paz, "BO-C"},
    {Tz::America_La_Paz, "BO-H"},
    {Tz::America_La_Paz, "BO-L"},
    {Tz::America_La_Paz, "BO-N"},
    {Tz::America_La_Paz, "BO-O"},
    {Tz::America_La_Paz, "BO-P"},
    {Tz::America_La_Paz, "BO-S"},
    {Tz::America_La_Paz, "BO-T"},
    {Tz::America_Lima},
    {Tz::America_Lima, "PE"},
    {Tz::America_Lima, "PE-AMA"},
    {Tz::America_Lima, "PE-ANC"},
    {Tz::America_Lima, "PE-APU"},
    {Tz::America_Lima, "PE-ARE"},
    {Tz::America_Lima, "PE-AYA"},
    {Tz::America_Lima, "PE-CAJ"},
    {Tz::America_Lima, "PE-CAL"},
    {Tz::America_Lima, "PE-CUS"},
    {Tz::America_Lima, "PE-HUC"},
    {Tz::America_Lima, "PE-HUV"},
    {Tz::America_Lima, "PE-ICA"},
    {Tz::America_Lima, "PE-JUN"},
    {Tz::America_Lima, "PE-LAL"},
    {Tz::America_Lima, "PE-LAM"},
    {Tz::America_Lima, "PE-LIM"},
    {Tz::America_Lima, "PE-LOR"},
    {Tz::America_Lima, "PE-MDD"},
    {Tz::America_Lima, "PE-MOQ"},
    {Tz::America_Lima, "PE-PAS"},
    {Tz::America_Lima, "PE-PIU"},
    {Tz::America_Lima, "PE-PUN"},
    {Tz::America_Lima, "PE-SAM"},
    {Tz::America_Lima, "PE-TAC"},
    {Tz::America_Lima, "PE-TUM"},
    {Tz::America_Lima, "PE-UCA"},
    {Tz::America_Los_Angeles},
    {Tz::America_Los_Angeles, "US"},
    {Tz::America_Los_Angeles, "US-CA"},
    {Tz::America_Los_Angeles, "US-ID"},
    {Tz::America_Los_Angeles, "US-NV"},
    {Tz::America_Los_Angeles, "US-OR"},
    {Tz::America_Los_Angeles, "US-WA"},
    {Tz::America_Lower_Princes},
    {Tz::America_Maceio, "BR"},
    {Tz::America_Maceio, "BR-AL"},
    {Tz::America_Maceio, "BR-SE"},
    {Tz::America_Managua},
    {Tz::America_Managua, "NI"},
    {Tz::America_Managua, "NI-AN"},
    {Tz::America_Managua, "NI-AS"},
    {Tz::America_Managua, "NI-BO"},
    {Tz::America_Managua, "NI-CA"},
    {Tz::America_Managua, "NI-CI"},
    {Tz::America_Managua, "NI-CO"},
    {Tz::America_Managua, "NI-ES"},
    {Tz::America_Managua, "NI-GR"},
    {Tz::America_Managua, "NI-JI"},
    {Tz::America_Managua, "NI-LE"},
    {Tz::America_Managua, "NI-MD"},
    {Tz::America_Managua, "NI-MN"},
    {Tz::America_Managua, "NI-MT"},
    {Tz::America_Managua, "NI-NS"},
    {Tz::America_Managua, "NI-RI"},
    {Tz::America_Managua, "NI-SJ"},
    {Tz::America_Manaus},
    {Tz::America_Manaus, "BR"},
    {Tz::America_Manaus, "BR-AM"},
    {Tz::America_Marigot},
    {Tz::America_Marigot, "FR-MF"},
    {Tz::America_Marigot, "MF"},
    {Tz::America_Martinique, "FR-MQ"},
    {Tz::America_Martinique, "MQ"},
    {Tz::America_Matamoros},
    {Tz::America_Matamoros, "MX"},
    {Tz::America_Matamoros, "MX-COA"},
    {Tz::America_Matamoros, "MX-NLE"},
    {Tz::America_Matamoros, "MX-TAM"},
    {Tz::America_Mazatlan, "MX"},
    {Tz::America_Mazatlan, "MX-BCS"},
    {Tz::America_Mazatlan, "MX-NAY"},
    {Tz::America_Mazatlan, "MX-SIN"},
    {Tz::America_Menominee, "US"},
    {Tz::America_Menominee, "US-MI"},
    {Tz::America_Merida, "MX"},
    {Tz::America_Merida, "MX-CAM"},
    {Tz::America_Merida, "MX-YUC"},
    {Tz::America_Metlakatla, "US-AK"},
    {Tz::America_Mexico_City, "MX"},
    {Tz::America_Mexico_City, "MX-AGU"},
    {Tz::America_Mexico_City, "MX-CHP"},
    {Tz::America_Mexico_City, "MX-CMX"},
    {Tz::America_Mexico_City, "MX-COL"},
    {Tz::America_Mexico_City, "MX-GRO"},
    {Tz::America_Mexico_City, "MX-GUA"},
    {Tz::America_Mexico_City, "MX-HID"},
    {Tz::America_Mexico_City, "MX-JAL"},
    {Tz::America_Mexico_City, "MX-MEX"},
    {Tz::America_Mexico_City, "MX-MIC"},
    {Tz::America_Mexico_City, "MX-MOR"},
    {Tz::America_Mexico_City, "MX-OAX"},
    {Tz::America_Mexico_City, "MX-PUE"},
    {Tz::America_Mexico_City, "MX-QUE"},
    {Tz::America_Mexico_City, "MX-SLP"},
    {Tz::America_Mexico_City, "MX-TAB"},
    {Tz::America_Mexico_City, "MX-TLA"},
    {Tz::America_Mexico_City, "MX-VER"},
    {Tz::America_Mexico_City, "MX-ZAC"},
    {Tz::America_Miquelon, "PM"},
    {Tz::America_Moncton, "CA"},
    {Tz::America_Moncton, "CA-NB"},
    {Tz::America_Monterrey, "MX"},
    {Tz::America_Monterrey, "MX-COA"},
    {Tz::America_Monterrey, "MX-DUR"},
    {Tz::America_Monterrey, "MX-NLE"},
    {Tz::America_Monterrey, "MX-TAM"},
    {Tz::America_Montevideo},
    {Tz::America_Montevideo, "UY"},
    {Tz::America_Montevideo, "UY-AR"},
    {Tz::America_Montevideo, "UY-CA"},
    {Tz::America_Montevideo, "UY-CL"},
    {Tz::America_Montevideo, "UY-CO"},
    {Tz::America_Montevideo, "UY-DU"},
    {Tz::America_Montevideo, "UY-FD"},
    {Tz::America_Montevideo, "UY-FS"},
    {Tz::America_Montevideo, "UY-LA"},
    {Tz::America_Montevideo, "UY-MA"},
    {Tz::America_Montevideo, "UY-MO"},
    {Tz::America_Montevideo, "UY-PA"},
    {Tz::America_Montevideo, "UY-RN"},
    {Tz::America_Montevideo, "UY-RO"},
    {Tz::America_Montevideo, "UY-RV"},
    {Tz::America_Montevideo, "UY-SA"},
    {Tz::America_Montevideo, "UY-SJ"},
    {Tz::America_Montevideo, "UY-SO"},
    {Tz::America_Montevideo, "UY-TA"},
    {Tz::America_Montevideo, "UY-TT"},
    {Tz::America_Montserrat},
    {Tz::America_Montserrat, "MS"},
    {Tz::America_Nassau},
    {Tz::America_Nassau, "BS"},
    {Tz::America_Nassau, "BS-AK"},
    {Tz::America_Nassau, "BS-BI"},
    {Tz::America_Nassau, "BS-BY"},
    {Tz::America_Nassau, "BS-CE"},
    {Tz::America_Nassau, "BS-CI"},
    {Tz::America_Nassau, "BS-CK"},
    {Tz::America_Nassau, "BS-CO"},
    {Tz::America_Nassau, "BS-CS"},
    {Tz::America_Nassau, "BS-EG"},
    {Tz::America_Nassau, "BS-EX"},
    {Tz::America_Nassau, "BS-FP"},
    {Tz::America_Nassau, "BS-GC"},
    {Tz::America_Nassau, "BS-HT"},
    {Tz::America_Nassau, "BS-IN"},
    {Tz::America_Nassau, "BS-LI"},
    {Tz::America_Nassau, "BS-MC"},
    {Tz::America_Nassau, "BS-MG"},
    {Tz::America_Nassau, "BS-MI"},
    {Tz::America_Nassau, "BS-NE"},
    {Tz::America_Nassau, "BS-NO"},
    {Tz::America_Nassau, "BS-NP"},
    {Tz::America_Nassau, "BS-NS"},
    {Tz::America_Nassau, "BS-RC"},
    {Tz::America_Nassau, "BS-RI"},
    {Tz::America_Nassau, "BS-SA"},
    {Tz::America_Nassau, "BS-SE"},
    {Tz::America_Nassau, "BS-SO"},
    {Tz::America_Nassau, "BS-SS"},
    {Tz::America_Nassau, "BS-SW"},
    {Tz::America_Nassau, "BS-WG"},
    {Tz::America_New_York},
    {Tz::America_New_York, "US"},
    {Tz::America_New_York, "US-CT"},
    {Tz::America_New_York, "US-DE"},
    {Tz::America_New_York, "US-FL"},
    {Tz::America_New_York, "US-GA"},
    {Tz::America_New_York, "US-IN"},
    {Tz::America_New_York, "US-KY"},
    {Tz::America_New_York, "US-MA"},
    {Tz::America_New_York, "US-MD"},
    {Tz::America_New_York, "US-ME"},
    {Tz::America_New_York, "US-NC"},
    {Tz::America_New_York, "US-NH"},
    {Tz::America_New_York, "US-NJ"},
    {Tz::America_New_York, "US-NY"},
    {Tz::America_New_York, "US-OH"},
    {Tz::America_New_York, "US-PA"},
    {Tz::America_New_York, "US-RI"},
    {Tz::America_New_York, "US-SC"},
    {Tz::America_New_York, "US-TN"},
    {Tz::America_New_York, "US-VA"},
    {Tz::America_New_York, "US-VT"},
    {Tz::America_New_York, "US-WV"},
    {Tz::America_Nome, "US-AK"},
    {Tz::America_Noronha, "BR-PE"},
    {Tz::America_North_Dakota_Beulah, "US-ND"},
    {Tz::America_North_Dakota_Center, "US-ND"},
    {Tz::America_North_Dakota_New_Salem, "US-ND"},
    {Tz::America_Nuuk, "GL"},
    {Tz::America_Nuuk, "GL-AV"},
    {Tz::America_Nuuk, "GL-KU"},
    {Tz::America_Nuuk, "GL-QE"},
    {Tz::America_Nuuk, "GL-QT"},
    {Tz::America_Nuuk, "GL-SM"},
    {Tz::America_Ojinaga},
    {Tz::America_Ojinaga, "MX-CHH"},
    {Tz::America_Panama, "PA"},
    {Tz::America_Panama, "PA-1"},
    {Tz::America_Panama, "PA-10"},
    {Tz::America_Panama, "PA-2"},
    {Tz::America_Panama, "PA-3"},
    {Tz::America_Panama, "PA-4"},
    {Tz::America_Panama, "PA-5"},
    {Tz::America_Panama, "PA-6"},
    {Tz::America_Panama, "PA-7"},
    {Tz::America_Panama, "PA-8"},
    {Tz::America_Panama, "PA-9"},
    {Tz::America_Panama, "PA-EM"},
    {Tz::America_Panama, "PA-KY"},
    {Tz::America_Panama, "PA-NB"},
    {Tz::America_Pangnirtung, "CA"},
    {Tz::America_Pangnirtung, "CA-NU"},
    {Tz::America_Pangnirtung, "CA-QC"},
    {Tz::America_Paramaribo},
    {Tz::America_Paramaribo, "SR"},
    {Tz::America_Paramaribo, "SR-BR"},
    {Tz::America_Paramaribo, "SR-CM"},
    {Tz::America_Paramaribo, "SR-CR"},
    {Tz::America_Paramaribo, "SR-MA"},
    {Tz::America_Paramaribo, "SR-NI"},
    {Tz::America_Paramaribo, "SR-PR"},
    {Tz::America_Paramaribo, "SR-SA"},
    {Tz::America_Paramaribo, "SR-SI"},
    {Tz::America_Phoenix},
    {Tz::America_Phoenix, "US-AZ"},
    {Tz::America_Port_au_Prince, "HT"},
    {Tz::America_Port_au_Prince, "HT-AR"},
    {Tz::America_Port_au_Prince, "HT-CE"},
    {Tz::America_Port_au_Prince, "HT-GA"},
    {Tz::America_Port_au_Prince, "HT-ND"},
    {Tz::America_Port_au_Prince, "HT-NE"},
    {Tz::America_Port_au_Prince, "HT-NI"},
    {Tz::America_Port_au_Prince, "HT-NO"},
    {Tz::America_Port_au_Prince, "HT-OU"},
    {Tz::America_Port_au_Prince, "HT-SD"},
    {Tz::America_Port_au_Prince, "HT-SE"},
    {Tz::America_Port_of_Spain, "TT"},
    {Tz::America_Port_of_Spain, "TT-CTT"},
    {Tz::America_Port_of_Spain, "TT-DMN"},
    {Tz::America_Port_of_Spain, "TT-MRC"},
    {Tz::America_Port_of_Spain, "TT-PED"},
    {Tz::America_Port_of_Spain, "TT-SGE"},
    {Tz::America_Port_of_Spain, "TT-SIP"},
    {Tz::America_Port_of_Spain, "TT-TOB"},
    {Tz::America_Port_of_Spain, "TT-TUP"},
    {Tz::America_Porto_Velho},
    {Tz::America_Porto_Velho, "BR"},
    {Tz::America_Porto_Velho, "BR-RO"},
    {Tz::America_Puerto_Rico},
    {Tz::America_Puerto_Rico, "PR"},
    {Tz::America_Puerto_Rico, "US"},
    {Tz::America_Punta_Arenas},
    {Tz::America_Punta_Arenas, "CL-MA"},
    {Tz::America_Rainy_River},
    {Tz::America_Rainy_River, "CA"},
    {Tz::America_Rainy_River, "CA-ON"},
    {Tz::America_Rankin_Inlet, "CA"},
    {Tz::America_Rankin_Inlet, "CA-NU"},
    {Tz::America_Recife, "BR"},
    {Tz::America_Recife, "BR-PE"},
    {Tz::America_Regina, "CA-SK"},
    {Tz::America_Resolute, "CA-NU"},
    {Tz::America_Rio_Branco},
    {Tz::America_Rio_Branco, "BR"},
    {Tz::America_Rio_Branco, "BR-AC"},
    {Tz::America_Santarem},
    {Tz::America_Santarem, "BR"},
    {Tz::America_Santarem, "BR-PA"},
    {Tz::America_Santiago, "CL"},
    {Tz::America_Santiago, "CL-AI"},
    {Tz::America_Santiago, "CL-AN"},
    {Tz::America_Santiago, "CL-AP"},
    {Tz::America_Santiago, "CL-AR"},
    {Tz::America_Santiago, "CL-AT"},
    {Tz::America_Santiago, "CL-BI"},
    {Tz::America_Santiago, "CL-CO"},
    {Tz::America_Santiago, "CL-LI"},
    {Tz::America_Santiago, "CL-LL"},
    {Tz::America_Santiago, "CL-LR"},
    {Tz::America_Santiago, "CL-ML"},
    {Tz::America_Santiago, "CL-NB"},
    {Tz::America_Santiago, "CL-RM"},
    {Tz::America_Santiago, "CL-TA"},
    {Tz::America_Santiago, "CL-VS"},
    {Tz::America_Santo_Domingo},
    {Tz::America_Santo_Domingo, "DO"},
    {Tz::America_Sao_Paulo},
    {Tz::America_Sao_Paulo, "BR"},
    {Tz::America_Sao_Paulo, "BR-DF"},
    {Tz::America_Sao_Paulo, "BR-ES"},
    {Tz::America_Sao_Paulo, "BR-GO"},
    {Tz::America_Sao_Paulo, "BR-MG"},
    {Tz::America_Sao_Paulo, "BR-RJ"},
    {Tz::America_Sao_Paulo, "BR-RS"},
    {Tz::America_Sao_Paulo, "BR-SP"},
    {Tz::America_Scoresbysund, "GL"},
    {Tz::America_Scoresbysund, "GL-SM"},
    {Tz::America_Sitka, "US-AK"},
    {Tz::America_St_Barthelemy},
    {Tz::America_St_Barthelemy, "BL"},
    {Tz::America_St_Johns, "CA-NL"},
    {Tz::America_St_Kitts},
    {Tz::America_St_Kitts, "KN"},
    {Tz::America_St_Lucia},
    {Tz::America_St_Lucia, "LC"},
    {Tz::America_St_Lucia, "LC-02"},
    {Tz::America_St_Lucia, "LC-06"},
    {Tz::America_St_Lucia, "LC-07"},
    {Tz::America_St_Thomas},
    {Tz::America_St_Thomas, "US"},
    {Tz::America_St_Thomas, "US-VI"},
    {Tz::America_St_Thomas, "VI"},
    {Tz::America_St_Vincent},
    {Tz::America_St_Vincent, "VC"},
    {Tz::America_St_Vincent, "VC-01"},
    {Tz::America_St_Vincent, "VC-03"},
    {Tz::America_St_Vincent, "VC-04"},
    {Tz::America_St_Vincent, "VC-06"},
    {Tz::America_Swift_Current, "CA-SK"},
    {Tz::America_Tegucigalpa},
    {Tz::America_Tegucigalpa, "HN"},
    {Tz::America_Tegucigalpa, "HN-AT"},
    {Tz::America_Tegucigalpa, "HN-CH"},
    {Tz::America_Tegucigalpa, "HN-CL"},
    {Tz::America_Tegucigalpa, "HN-CM"},
    {Tz::America_Tegucigalpa, "HN-CP"},
    {Tz::America_Tegucigalpa, "HN-CR"},
    {Tz::America_Tegucigalpa, "HN-EP"},
    {Tz::America_Tegucigalpa, "HN-FM"},
    {Tz::America_Tegucigalpa, "HN-GD"},
    {Tz::America_Tegucigalpa, "HN-IB"},
    {Tz::America_Tegucigalpa, "HN-IN"},
    {Tz::America_Tegucigalpa, "HN-LE"},
    {Tz::America_Tegucigalpa, "HN-LP"},
    {Tz::America_Tegucigalpa, "HN-OC"},
    {Tz::America_Tegucigalpa, "HN-OL"},
    {Tz::America_Tegucigalpa, "HN-SB"},
    {Tz::America_Tegucigalpa, "HN-VA"},
    {Tz::America_Tegucigalpa, "HN-YO"},
    {Tz::America_Thule, "GL-AV"},
    {Tz::America_Thunder_Bay},
    {Tz::America_Thunder_Bay, "CA-ON"},
    {Tz::America_Tijuana},
    {Tz::America_Tijuana, "MX"},
    {Tz::America_Tijuana, "MX-BCN"},
    {Tz::America_Toronto},
    {Tz::America_Toronto, "CA"},
    {Tz::America_Toronto, "CA-ON"},
    {Tz::America_Toronto, "CA-QC"},
    {Tz::America_Tortola},
    {Tz::America_Tortola, "VG"},
    {Tz::America_Vancouver},
    {Tz::America_Vancouver, "CA"},
    {Tz::America_Vancouver, "CA-BC"},
    {Tz::America_Whitehorse, "CA"},
    {Tz::America_Whitehorse, "CA-YT"},
    {Tz::America_Winnipeg},
    {Tz::America_Winnipeg, "CA"},
    {Tz::America_Winnipeg, "CA-MB"},
    {Tz::America_Winnipeg, "CA-ON"},
    {Tz::America_Winnipeg, "CA-SK"},
    {Tz::America_Yakutat, "US-AK"},
    {Tz::America_Yellowknife, "CA"},
    {Tz::America_Yellowknife, "CA-NT"},
    {Tz::Antarctica_Macquarie, "AU-TAS"},
    {Tz::Asia_Aden},
    {Tz::Asia_Aden, "YE"},
    {Tz::Asia_Aden, "YE-AB"},
    {Tz::Asia_Aden, "YE-AD"},
    {Tz::Asia_Aden, "YE-AM"},
    {Tz::Asia_Aden, "YE-BA"},
    {Tz::Asia_Aden, "YE-DA"},
    {Tz::Asia_Aden, "YE-DH"},
    {Tz::Asia_Aden, "YE-HD"},
    {Tz::Asia_Aden, "YE-HJ"},
    {Tz::Asia_Aden, "YE-HU"},
    {Tz::Asia_Aden, "YE-IB"},
    {Tz::Asia_Aden, "YE-JA"},
    {Tz::Asia_Aden, "YE-LA"},
    {Tz::Asia_Aden, "YE-MA"},
    {Tz::Asia_Aden, "YE-MR"},
    {Tz::Asia_Aden, "YE-MW"},
    {Tz::Asia_Aden, "YE-RA"},
    {Tz::Asia_Aden, "YE-SD"},
    {Tz::Asia_Aden, "YE-SH"},
    {Tz::Asia_Aden, "YE-SN"},
    {Tz::Asia_Aden, "YE-SU"},
    {Tz::Asia_Aden, "YE-TA"},
    {Tz::Asia_Almaty},
    {Tz::Asia_Almaty, "KZ"},
    {Tz::Asia_Almaty, "KZ-AKM"},
    {Tz::Asia_Almaty, "KZ-ALA"},
    {Tz::Asia_Almaty, "KZ-ALM"},
    {Tz::Asia_Almaty, "KZ-AST"},
    {Tz::Asia_Almaty, "KZ-KAR"},
    {Tz::Asia_Almaty, "KZ-PAV"},
    {Tz::Asia_Almaty, "KZ-SEV"},
    {Tz::Asia_Almaty, "KZ-SHY"},
    {Tz::Asia_Almaty, "KZ-VOS"},
    {Tz::Asia_Almaty, "KZ-YUZ"},
    {Tz::Asia_Almaty, "KZ-ZHA"},
    {Tz::Asia_Amman, "JO"},
    {Tz::Asia_Amman, "JO-AM"},
    {Tz::Asia_Amman, "JO-AQ"},
    {Tz::Asia_Amman, "JO-AT"},
    {Tz::Asia_Amman, "JO-AZ"},
    {Tz::Asia_Amman, "JO-BA"},
    {Tz::Asia_Amman, "JO-IR"},
    {Tz::Asia_Amman, "JO-KA"},
    {Tz::Asia_Amman, "JO-MA"},
    {Tz::Asia_Amman, "JO-MD"},
    {Tz::Asia_Amman, "JO-MN"},
    {Tz::Asia_Anadyr, "RU"},
    {Tz::Asia_Anadyr, "RU-CHU"},
    {Tz::Asia_Aqtau},
    {Tz::Asia_Aqtau, "KZ"},
    {Tz::Asia_Aqtau, "KZ-MAN"},
    {Tz::Asia_Aqtobe},
    {Tz::Asia_Aqtobe, "KZ"},
    {Tz::Asia_Aqtobe, "KZ-AKT"},
    {Tz::Asia_Ashgabat},
    {Tz::Asia_Ashgabat, "TM"},
    {Tz::Asia_Ashgabat, "TM-A"},
    {Tz::Asia_Ashgabat, "TM-B"},
    {Tz::Asia_Ashgabat, "TM-D"},
    {Tz::Asia_Ashgabat, "TM-L"},
    {Tz::Asia_Ashgabat, "TM-M"},
    {Tz::Asia_Ashgabat, "TM-S"},
    {Tz::Asia_Atyrau, "KZ"},
    {Tz::Asia_Atyrau, "KZ-ATY"},
    {Tz::Asia_Baghdad},
    {Tz::Asia_Baghdad, "IQ"},
    {Tz::Asia_Baghdad, "IQ-AN"},
    {Tz::Asia_Baghdad, "IQ-AR"},
    {Tz::Asia_Baghdad, "IQ-BA"},
    {Tz::Asia_Baghdad, "IQ-BB"},
    {Tz::Asia_Baghdad, "IQ-BG"},
    {Tz::Asia_Baghdad, "IQ-DA"},
    {Tz::Asia_Baghdad, "IQ-DI"},
    {Tz::Asia_Baghdad, "IQ-DQ"},
    {Tz::Asia_Baghdad, "IQ-HA"},
    {Tz::Asia_Baghdad, "IQ-KA"},
    {Tz::Asia_Baghdad, "IQ-KI"},
    {Tz::Asia_Baghdad, "IQ-MA"},
    {Tz::Asia_Baghdad, "IQ-MU"},
    {Tz::Asia_Baghdad, "IQ-NA"},
    {Tz::Asia_Baghdad, "IQ-NI"},
    {Tz::Asia_Baghdad, "IQ-QA"},
    {Tz::Asia_Baghdad, "IQ-SD"},
    {Tz::Asia_Baghdad, "IQ-SU"},
    {Tz::Asia_Baghdad, "IQ-WA"},
    {Tz::Asia_Bahrain},
    {Tz::Asia_Bahrain, "BH"},
    {Tz::Asia_Bahrain, "BH-14"},
    {Tz::Asia_Bahrain, "BH-15"},
    {Tz::Asia_Bahrain, "BH-17"},
    {Tz::Asia_Baku},
    {Tz::Asia_Baku, "AZ"},
    {Tz::Asia_Baku, "AZ-ABS"},
    {Tz::Asia_Baku, "AZ-AGA"},
    {Tz::Asia_Baku, "AZ-AGC"},
    {Tz::Asia_Baku, "AZ-AGM"},
    {Tz::Asia_Baku, "AZ-AGS"},
    {Tz::Asia_Baku, "AZ-AGU"},
    {Tz::Asia_Baku, "AZ-AST"},
    {Tz::Asia_Baku, "AZ-BA"},
    {Tz::Asia_Baku, "AZ-BAL"},
    {Tz::Asia_Baku, "AZ-BAR"},
    {Tz::Asia_Baku, "AZ-BEY"},
    {Tz::Asia_Baku, "AZ-BIL"},
    {Tz::Asia_Baku, "AZ-CAB"},
    {Tz::Asia_Baku, "AZ-CAL"},
    {Tz::Asia_Baku, "AZ-DAS"},
    {Tz::Asia_Baku, "AZ-FUZ"},
    {Tz::Asia_Baku, "AZ-GAD"},
    {Tz::Asia_Baku, "AZ-GOR"},
    {Tz::Asia_Baku, "AZ-GOY"},
    {Tz::Asia_Baku, "AZ-GYG"},
    {Tz::Asia_Baku, "AZ-HAC"},
    {Tz::Asia_Baku, "AZ-IMI"},
    {Tz::Asia_Baku, "AZ-ISM"},
    {Tz::Asia_Baku, "AZ-KAL"},
    {Tz::Asia_Baku, "AZ-KUR"},
    {Tz::Asia_Baku, "AZ-LAC"},
    {Tz::Asia_Baku, "AZ-LAN"},
    {Tz::Asia_Baku, "AZ-LER"},
    {Tz::Asia_Baku, "AZ-NEF"},
    {Tz::Asia_Baku, "AZ-OGU"},
    {Tz::Asia_Baku, "AZ-QAB"},
    {Tz::Asia_Baku, "AZ-QAX"},
    {Tz::Asia_Baku, "AZ-QAZ"},
    {Tz::Asia_Baku, "AZ-QBA"},
    {Tz::Asia_Baku, "AZ-QBI"},
    {Tz::Asia_Baku, "AZ-QOB"},
    {Tz::Asia_Baku, "AZ-QUS"},
    {Tz::Asia_Baku, "AZ-SAB"},
    {Tz::Asia_Baku, "AZ-SAK"},
    {Tz::Asia_Baku, "AZ-SAL"},
    {Tz::Asia_Baku, "AZ-SAT"},
    {Tz::Asia_Baku, "AZ-SBN"},
    {Tz::Asia_Baku, "AZ-SIY"},
    {Tz::Asia_Baku, "AZ-SKR"},
    {Tz::Asia_Baku, "AZ-SM"},
    {Tz::Asia_Baku, "AZ-SMI"},
    {Tz::Asia_Baku, "AZ-SMX"},
    {Tz::Asia_Baku, "AZ-SUS"},
    {Tz::Asia_Baku, "AZ-TAR"},
    {Tz::Asia_Baku, "AZ-TOV"},
    {Tz::Asia_Baku, "AZ-UCA"},
    {Tz::Asia_Baku, "AZ-XAC"},
    {Tz::Asia_Baku, "AZ-XCI"},
    {Tz::Asia_Baku, "AZ-XIZ"},
    {Tz::Asia_Baku, "AZ-XVD"},
    {Tz::Asia_Baku, "AZ-YEV"},
    {Tz::Asia_Baku, "AZ-ZAN"},
    {Tz::Asia_Baku, "AZ-ZAQ"},
    {Tz::Asia_Baku, "AZ-ZAR"},
    {Tz::Asia_Bangkok},
    {Tz::Asia_Bangkok, "TH"},
    {Tz::Asia_Bangkok, "TH-10"},
    {Tz::Asia_Bangkok, "TH-11"},
    {Tz::Asia_Bangkok, "TH-13"},
    {Tz::Asia_Bangkok, "TH-14"},
    {Tz::Asia_Bangkok, "TH-16"},
    {Tz::Asia_Bangkok, "TH-18"},
    {Tz::Asia_Bangkok, "TH-19"},
    {Tz::Asia_Bangkok, "TH-20"},
    {Tz::Asia_Bangkok, "TH-21"},
    {Tz::Asia_Bangkok, "TH-22"},
    {Tz::Asia_Bangkok, "TH-23"},
    {Tz::Asia_Bangkok, "TH-24"},
    {Tz::Asia_Bangkok, "TH-25"},
    {Tz::Asia_Bangkok, "TH-26"},
    {Tz::Asia_Bangkok, "TH-27"},
    {Tz::Asia_Bangkok, "TH-30"},
    {Tz::Asia_Bangkok, "TH-31"},
    {Tz::Asia_Bangkok, "TH-32"},
    {Tz::Asia_Bangkok, "TH-33"},
    {Tz::Asia_Bangkok, "TH-34"},
    {Tz::Asia_Bangkok, "TH-35"},
    {Tz::Asia_Bangkok, "TH-36"},
    {Tz::Asia_Bangkok, "TH-37"},
    {Tz::Asia_Bangkok, "TH-38"},
    {Tz::Asia_Bangkok, "TH-39"},
    {Tz::Asia_Bangkok, "TH-40"},
    {Tz::Asia_Bangkok, "TH-41"},
    {Tz::Asia_Bangkok, "TH-42"},
    {Tz::Asia_Bangkok, "TH-43"},
    {Tz::Asia_Bangkok, "TH-44"},
    {Tz::Asia_Bangkok, "TH-45"},
    {Tz::Asia_Bangkok, "TH-46"},
    {Tz::Asia_Bangkok, "TH-47"},
    {Tz::Asia_Bangkok, "TH-48"},
    {Tz::Asia_Bangkok, "TH-49"},
    {Tz::Asia_Bangkok, "TH-50"},
    {Tz::Asia_Bangkok, "TH-51"},
    {Tz::Asia_Bangkok, "TH-52"},
    {Tz::Asia_Bangkok, "TH-53"},
    {Tz::Asia_Bangkok, "TH-54"},
    {Tz::Asia_Bangkok, "TH-55"},
    {Tz::Asia_Bangkok, "TH-56"},
    {Tz::Asia_Bangkok, "TH-57"},
    {Tz::Asia_Bangkok, "TH-58"},
    {Tz::Asia_Bangkok, "TH-60"},
    {Tz::Asia_Bangkok, "TH-61"},
    {Tz::Asia_Bangkok, "TH-62"},
    {Tz::Asia_Bangkok, "TH-63"},
    {Tz::Asia_Bangkok, "TH-64"},
    {Tz::Asia_Bangkok, "TH-65"},
    {Tz::Asia_Bangkok, "TH-66"},
    {Tz::Asia_Bangkok, "TH-67"},
    {Tz::Asia_Bangkok, "TH-70"},
    {Tz::Asia_Bangkok, "TH-71"},
    {Tz::Asia_Bangkok, "TH-72"},
    {Tz::Asia_Bangkok, "TH-73"},
    {Tz::Asia_Bangkok, "TH-74"},
    {Tz::Asia_Bangkok, "TH-76"},
    {Tz::Asia_Bangkok, "TH-77"},
    {Tz::Asia_Bangkok, "TH-80"},
    {Tz::Asia_Bangkok, "TH-81"},
    {Tz::Asia_Bangkok, "TH-82"},
    {Tz::Asia_Bangkok, "TH-83"},
    {Tz::Asia_Bangkok, "TH-84"},
    {Tz::Asia_Bangkok, "TH-85"},
    {Tz::Asia_Bangkok, "TH-86"},
    {Tz::Asia_Bangkok, "TH-90"},
    {Tz::Asia_Bangkok, "TH-91"},
    {Tz::Asia_Bangkok, "TH-92"},
    {Tz::Asia_Bangkok, "TH-93"},
    {Tz::Asia_Bangkok, "TH-94"},
    {Tz::Asia_Bangkok, "TH-95"},
    {Tz::Asia_Bangkok, "TH-96"},
    {Tz::Asia_Bangkok, "VN"},
    {Tz::Asia_Bangkok, "VN-01"},
    {Tz::Asia_Bangkok, "VN-02"},
    {Tz::Asia_Bangkok, "VN-03"},
    {Tz::Asia_Bangkok, "VN-04"},
    {Tz::Asia_Bangkok, "VN-05"},
    {Tz::Asia_Bangkok, "VN-06"},
    {Tz::Asia_Bangkok, "VN-07"},
    {Tz::Asia_Bangkok, "VN-09"},
    {Tz::Asia_Bangkok, "VN-13"},
    {Tz::Asia_Bangkok, "VN-14"},
    {Tz::Asia_Bangkok, "VN-18"},
    {Tz::Asia_Bangkok, "VN-20"},
    {Tz::Asia_Bangkok, "VN-21"},
    {Tz::Asia_Bangkok, "VN-22"},
    {Tz::Asia_Bangkok, "VN-23"},
    {Tz::Asia_Bangkok, "VN-24"},
    {Tz::Asia_Bangkok, "VN-53"},
    {Tz::Asia_Bangkok, "VN-54"},
    {Tz::Asia_Bangkok, "VN-56"},
    {Tz::Asia_Bangkok, "VN-61"},
    {Tz::Asia_Bangkok, "VN-63"},
    {Tz::Asia_Bangkok, "VN-67"},
    {Tz::Asia_Bangkok, "VN-68"},
    {Tz::Asia_Bangkok, "VN-69"},
    {Tz::Asia_Bangkok, "VN-70"},
    {Tz::Asia_Bangkok, "VN-71"},
    {Tz::Asia_Bangkok, "VN-HN"},
    {Tz::Asia_Bangkok, "VN-HP"},
    {Tz::Asia_Barnaul},
    {Tz::Asia_Barnaul, "RU"},
    {Tz::Asia_Barnaul, "RU-AL"},
    {Tz::Asia_Barnaul, "RU-ALT"},
    {Tz::Asia_Beirut, "LB"},
    {Tz::Asia_Beirut, "LB-AK"},
    {Tz::Asia_Beirut, "LB-AS"},
    {Tz::Asia_Beirut, "LB-BH"},
    {Tz::Asia_Beirut, "LB-BI"},
    {Tz::Asia_Beirut, "LB-JA"},
    {Tz::Asia_Beirut, "LB-JL"},
    {Tz::Asia_Beirut, "LB-NA"},
    {Tz::Asia_Bishkek},
    {Tz::Asia_Bishkek, "KG"},
    {Tz::Asia_Bishkek, "KG-B"},
    {Tz::Asia_Bishkek, "KG-C"},
    {Tz::Asia_Bishkek, "KG-J"},
    {Tz::Asia_Bishkek, "KG-N"},
    {Tz::Asia_Bishkek, "KG-O"},
    {Tz::Asia_Bishkek, "KG-T"},
    {Tz::Asia_Bishkek, "KG-Y"},
    {Tz::Asia_Brunei},
    {Tz::Asia_Brunei, "BN"},
    {Tz::Asia_Brunei, "BN-BE"},
    {Tz::Asia_Brunei, "BN-BM"},
    {Tz::Asia_Brunei, "BN-TU"},
    {Tz::Asia_Chita, "RU"},
    {Tz::Asia_Chita, "RU-ZAB"},
    {Tz::Asia_Choibalsan, "MN"},
    {Tz::Asia_Choibalsan, "MN-051"},
    {Tz::Asia_Choibalsan, "MN-061"},
    {Tz::Asia_Colombo, "LK"},
    {Tz::Asia_Colombo, "LK-1"},
    {Tz::Asia_Colombo, "LK-2"},
    {Tz::Asia_Colombo, "LK-3"},
    {Tz::Asia_Colombo, "LK-4"},
    {Tz::Asia_Colombo, "LK-5"},
    {Tz::Asia_Colombo, "LK-6"},
    {Tz::Asia_Colombo, "LK-7"},
    {Tz::Asia_Colombo, "LK-8"},
    {Tz::Asia_Colombo, "LK-9"},
    {Tz::Asia_Damascus, "SY"},
    {Tz::Asia_Damascus, "SY-DR"},
    {Tz::Asia_Damascus, "SY-DY"},
    {Tz::Asia_Damascus, "SY-HA"},
    {Tz::Asia_Damascus, "SY-HI"},
    {Tz::Asia_Damascus, "SY-HL"},
    {Tz::Asia_Damascus, "SY-HM"},
    {Tz::Asia_Damascus, "SY-ID"},
    {Tz::Asia_Damascus, "SY-LA"},
    {Tz::Asia_Damascus, "SY-RA"},
    {Tz::Asia_Damascus, "SY-RD"},
    {Tz::Asia_Damascus, "SY-SU"},
    {Tz::Asia_Damascus, "SY-TA"},
    {Tz::Asia_Dhaka, "BD"},
    {Tz::Asia_Dhaka, "BD-A"},
    {Tz::Asia_Dhaka, "BD-B"},
    {Tz::Asia_Dhaka, "BD-C"},
    {Tz::Asia_Dhaka, "BD-D"},
    {Tz::Asia_Dhaka, "BD-E"},
    {Tz::Asia_Dhaka, "BD-F"},
    {Tz::Asia_Dhaka, "BD-G"},
    {Tz::Asia_Dhaka, "BD-H"},
    {Tz::Asia_Dili},
    {Tz::Asia_Dili, "TL"},
    {Tz::Asia_Dili, "TL-BA"},
    {Tz::Asia_Dili, "TL-BO"},
    {Tz::Asia_Dili, "TL-CO"},
    {Tz::Asia_Dili, "TL-DI"},
    {Tz::Asia_Dili, "TL-LA"},
    {Tz::Asia_Dili, "TL-LI"},
    {Tz::Asia_Dili, "TL-MF"},
    {Tz::Asia_Dili, "TL-MT"},
    {Tz::Asia_Dili, "TL-OE"},
    {Tz::Asia_Dili, "TL-VI"},
    {Tz::Asia_Dubai},
    {Tz::Asia_Dubai, "AE"},
    {Tz::Asia_Dubai, "AE-AZ"},
    {Tz::Asia_Dubai, "AE-DU"},
    {Tz::Asia_Dubai, "AE-FU"},
    {Tz::Asia_Dubai, "AE-RK"},
    {Tz::Asia_Dubai, "AE-SH"},
    {Tz::Asia_Dubai, "AE-UQ"},
    {Tz::Asia_Dushanbe},
    {Tz::Asia_Dushanbe, "TJ"},
    {Tz::Asia_Dushanbe, "TJ-DU"},
    {Tz::Asia_Dushanbe, "TJ-GB"},
    {Tz::Asia_Dushanbe, "TJ-KT"},
    {Tz::Asia_Dushanbe, "TJ-RA"},
    {Tz::Asia_Dushanbe, "TJ-SU"},
    {Tz::Asia_Gaza, "PS"},
    {Tz::Asia_Gaza, "PS-GZA"},
    {Tz::Asia_Ho_Chi_Minh},
    {Tz::Asia_Ho_Chi_Minh, "VN"},
    {Tz::Asia_Ho_Chi_Minh, "VN-25"},
    {Tz::Asia_Ho_Chi_Minh, "VN-26"},
    {Tz::Asia_Ho_Chi_Minh, "VN-27"},
    {Tz::Asia_Ho_Chi_Minh, "VN-28"},
    {Tz::Asia_Ho_Chi_Minh, "VN-29"},
    {Tz::Asia_Ho_Chi_Minh, "VN-30"},
    {Tz::Asia_Ho_Chi_Minh, "VN-31"},
    {Tz::Asia_Ho_Chi_Minh, "VN-32"},
    {Tz::Asia_Ho_Chi_Minh, "VN-33"},
    {Tz::Asia_Ho_Chi_Minh, "VN-34"},
    {Tz::Asia_Ho_Chi_Minh, "VN-35"},
    {Tz::Asia_Ho_Chi_Minh, "VN-36"},
    {Tz::Asia_Ho_Chi_Minh, "VN-37"},
    {Tz::Asia_Ho_Chi_Minh, "VN-39"},
    {Tz::Asia_Ho_Chi_Minh, "VN-40"},
    {Tz::Asia_Ho_Chi_Minh, "VN-41"},
    {Tz::Asia_Ho_Chi_Minh, "VN-43"},
    {Tz::Asia_Ho_Chi_Minh, "VN-44"},
    {Tz::Asia_Ho_Chi_Minh, "VN-45"},
    {Tz::Asia_Ho_Chi_Minh, "VN-46"},
    {Tz::Asia_Ho_Chi_Minh, "VN-47"},
    {Tz::Asia_Ho_Chi_Minh, "VN-49"},
    {Tz::Asia_Ho_Chi_Minh, "VN-50"},
    {Tz::Asia_Ho_Chi_Minh, "VN-51"},
    {Tz::Asia_Ho_Chi_Minh, "VN-52"},
    {Tz::Asia_Ho_Chi_Minh, "VN-55"},
    {Tz::Asia_Ho_Chi_Minh, "VN-57"},
    {Tz::Asia_Ho_Chi_Minh, "VN-58"},
    {Tz::Asia_Ho_Chi_Minh, "VN-59"},
    {Tz::Asia_Ho_Chi_Minh, "VN-72"},
    {Tz::Asia_Ho_Chi_Minh, "VN-73"},
    {Tz::Asia_Ho_Chi_Minh, "VN-CT"},
    {Tz::Asia_Ho_Chi_Minh, "VN-DN"},
    {Tz::Asia_Ho_Chi_Minh, "VN-SG"},
    {Tz::Asia_Hong_Kong, "HK"},
    {Tz::Asia_Hovd},
    {Tz::Asia_Hovd, "MN"},
    {Tz::Asia_Hovd, "MN-043"},
    {Tz::Asia_Hovd, "MN-046"},
    {Tz::Asia_Hovd, "MN-057"},
    {Tz::Asia_Hovd, "MN-065"},
    {Tz::Asia_Hovd, "MN-071"},
    {Tz::Asia_Irkutsk},
    {Tz::Asia_Irkutsk, "RU"},
    {Tz::Asia_Irkutsk, "RU-BU"},
    {Tz::Asia_Irkutsk, "RU-IRK"},
    {Tz::Asia_Jakarta, "ID"},
    {Tz::Asia_Jayapura},
    {Tz::Asia_Jayapura, "ID"},
    {Tz::Asia_Jerusalem, "IL"},
    {Tz::Asia_Jerusalem, "IL-D"},
    {Tz::Asia_Jerusalem, "IL-HA"},
    {Tz::Asia_Jerusalem, "IL-JM"},
    {Tz::Asia_Jerusalem, "IL-M"},
    {Tz::Asia_Jerusalem, "IL-TA"},
    {Tz::Asia_Jerusalem, "IL-Z"},
    {Tz::Asia_Kabul, "AF"},
    {Tz::Asia_Kabul, "AF-BAL"},
    {Tz::Asia_Kabul, "AF-BAM"},
    {Tz::Asia_Kabul, "AF-BDG"},
    {Tz::Asia_Kabul, "AF-BDS"},
    {Tz::Asia_Kabul, "AF-BGL"},
    {Tz::Asia_Kabul, "AF-DAY"},
    {Tz::Asia_Kabul, "AF-FRA"},
    {Tz::Asia_Kabul, "AF-FYB"},
    {Tz::Asia_Kabul, "AF-GHA"},
    {Tz::Asia_Kabul, "AF-GHO"},
    {Tz::Asia_Kabul, "AF-HEL"},
    {Tz::Asia_Kabul, "AF-HER"},
    {Tz::Asia_Kabul, "AF-JOW"},
    {Tz::Asia_Kabul, "AF-KAB"},
    {Tz::Asia_Kabul, "AF-KAN"},
    {Tz::Asia_Kabul, "AF-KAP"},
    {Tz::Asia_Kabul, "AF-KDZ"},
    {Tz::Asia_Kabul, "AF-KHO"},
    {Tz::Asia_Kabul, "AF-KNR"},
    {Tz::Asia_Kabul, "AF-LAG"},
    {Tz::Asia_Kabul, "AF-LOG"},
    {Tz::Asia_Kabul, "AF-NAN"},
    {Tz::Asia_Kabul, "AF-NIM"},
    {Tz::Asia_Kabul, "AF-NUR"},
    {Tz::Asia_Kabul, "AF-PAN"},
    {Tz::Asia_Kabul, "AF-PAR"},
    {Tz::Asia_Kabul, "AF-PIA"},
    {Tz::Asia_Kabul, "AF-PKA"},
    {Tz::Asia_Kabul, "AF-SAM"},
    {Tz::Asia_Kabul, "AF-SAR"},
    {Tz::Asia_Kabul, "AF-TAK"},
    {Tz::Asia_Kabul, "AF-URU"},
    {Tz::Asia_Kabul, "AF-WAR"},
    {Tz::Asia_Kabul, "AF-ZAB"},
    {Tz::Asia_Kamchatka, "RU"},
    {Tz::Asia_Kamchatka, "RU-KAM"},
    {Tz::Asia_Karachi, "PK"},
    {Tz::Asia_Karachi, "PK-BA"},
    {Tz::Asia_Karachi, "PK-GB"},
    {Tz::Asia_Karachi, "PK-IS"},
    {Tz::Asia_Karachi, "PK-JK"},
    {Tz::Asia_Karachi, "PK-KP"},
    {Tz::Asia_Karachi, "PK-PB"},
    {Tz::Asia_Karachi, "PK-SD"},
    {Tz::Asia_Kathmandu, "NP"},
    {Tz::Asia_Kathmandu, "NP-P1"},
    {Tz::Asia_Kathmandu, "NP-P2"},
    {Tz::Asia_Kathmandu, "NP-P3"},
    {Tz::Asia_Kathmandu, "NP-P4"},
    {Tz::Asia_Kathmandu, "NP-P5"},
    {Tz::Asia_Kathmandu, "NP-P6"},
    {Tz::Asia_Kathmandu, "NP-P7"},
    {Tz::Asia_Khandyga, "RU-SA"},
    {Tz::Asia_Kolkata},
    {Tz::Asia_Kolkata, "IN"},
    {Tz::Asia_Kolkata, "IN-AN"},
    {Tz::Asia_Kolkata, "IN-AP"},
    {Tz::Asia_Kolkata, "IN-AR"},
    {Tz::Asia_Kolkata, "IN-AS"},
    {Tz::Asia_Kolkata, "IN-BR"},
    {Tz::Asia_Kolkata, "IN-CT"},
    {Tz::Asia_Kolkata, "IN-DL"},
    {Tz::Asia_Kolkata, "IN-GA"},
    {Tz::Asia_Kolkata, "IN-GJ"},
    {Tz::Asia_Kolkata, "IN-HP"},
    {Tz::Asia_Kolkata, "IN-HR"},
    {Tz::Asia_Kolkata, "IN-JH"},
    {Tz::Asia_Kolkata, "IN-JK"},
    {Tz::Asia_Kolkata, "IN-KA"},
    {Tz::Asia_Kolkata, "IN-KL"},
    {Tz::Asia_Kolkata, "IN-LA"},
    {Tz::Asia_Kolkata, "IN-LD"},
    {Tz::Asia_Kolkata, "IN-MH"},
    {Tz::Asia_Kolkata, "IN-ML"},
    {Tz::Asia_Kolkata, "IN-MN"},
    {Tz::Asia_Kolkata, "IN-MP"},
    {Tz::Asia_Kolkata, "IN-MZ"},
    {Tz::Asia_Kolkata, "IN-NL"},
    {Tz::Asia_Kolkata, "IN-OR"},
    {Tz::Asia_Kolkata, "IN-PB"},
    {Tz::Asia_Kolkata, "IN-PY"},
    {Tz::Asia_Kolkata, "IN-RJ"},
    {Tz::Asia_Kolkata, "IN-SK"},
    {Tz::Asia_Kolkata, "IN-TG"},
    {Tz::Asia_Kolkata, "IN-TN"},
    {Tz::Asia_Kolkata, "IN-TR"},
    {Tz::Asia_Kolkata, "IN-UP"},
    {Tz::Asia_Kolkata, "IN-UT"},
    {Tz::Asia_Kolkata, "IN-WB"},
    {Tz::Asia_Krasnoyarsk},
    {Tz::Asia_Krasnoyarsk, "RU"},
    {Tz::Asia_Krasnoyarsk, "RU-KK"},
    {Tz::Asia_Krasnoyarsk, "RU-KYA"},
    {Tz::Asia_Krasnoyarsk, "RU-TY"},
    {Tz::Asia_Kuala_Lumpur},
    {Tz::Asia_Kuala_Lumpur, "MY"},
    {Tz::Asia_Kuala_Lumpur, "MY-01"},
    {Tz::Asia_Kuala_Lumpur, "MY-02"},
    {Tz::Asia_Kuala_Lumpur, "MY-03"},
    {Tz::Asia_Kuala_Lumpur, "MY-04"},
    {Tz::Asia_Kuala_Lumpur, "MY-05"},
    {Tz::Asia_Kuala_Lumpur, "MY-06"},
    {Tz::Asia_Kuala_Lumpur, "MY-07"},
    {Tz::Asia_Kuala_Lumpur, "MY-08"},
    {Tz::Asia_Kuala_Lumpur, "MY-09"},
    {Tz::Asia_Kuala_Lumpur, "MY-10"},
    {Tz::Asia_Kuala_Lumpur, "MY-11"},
    {Tz::Asia_Kuala_Lumpur, "MY-12"},
    {Tz::Asia_Kuala_Lumpur, "MY-13"},
    {Tz::Asia_Kuala_Lumpur, "MY-15"},
    {Tz::Asia_Kuwait},
    {Tz::Asia_Kuwait, "KW"},
    {Tz::Asia_Kuwait, "KW-AH"},
    {Tz::Asia_Kuwait, "KW-JA"},
    {Tz::Asia_Kuwait, "KW-KU"},
    {Tz::Asia_Macau, "MO"},
    {Tz::Asia_Magadan, "RU"},
    {Tz::Asia_Magadan, "RU-MAG"},
    {Tz::Asia_Makassar},
    {Tz::Asia_Makassar, "ID"},
    {Tz::Asia_Makassar, "ID-KA"},
    {Tz::Asia_Manila, "PH"},
    {Tz::Asia_Manila, "PH-00"},
    {Tz::Asia_Manila, "PH-01"},
    {Tz::Asia_Manila, "PH-02"},
    {Tz::Asia_Manila, "PH-03"},
    {Tz::Asia_Manila, "PH-05"},
    {Tz::Asia_Manila, "PH-06"},
    {Tz::Asia_Manila, "PH-07"},
    {Tz::Asia_Manila, "PH-08"},
    {Tz::Asia_Manila, "PH-09"},
    {Tz::Asia_Manila, "PH-10"},
    {Tz::Asia_Manila, "PH-11"},
    {Tz::Asia_Manila, "PH-12"},
    {Tz::Asia_Manila, "PH-13"},
    {Tz::Asia_Manila, "PH-14"},
    {Tz::Asia_Manila, "PH-15"},
    {Tz::Asia_Manila, "PH-40"},
    {Tz::Asia_Manila, "PH-41"},
    {Tz::Asia_Muscat},
    {Tz::Asia_Muscat, "OM"},
    {Tz::Asia_Muscat, "OM-BJ"},
    {Tz::Asia_Muscat, "OM-BS"},
    {Tz::Asia_Muscat, "OM-BU"},
    {Tz::Asia_Muscat, "OM-DA"},
    {Tz::Asia_Muscat, "OM-MA"},
    {Tz::Asia_Muscat, "OM-MU"},
    {Tz::Asia_Muscat, "OM-SJ"},
    {Tz::Asia_Muscat, "OM-SS"},
    {Tz::Asia_Muscat, "OM-WU"},
    {Tz::Asia_Muscat, "OM-ZA"},
    {Tz::Asia_Muscat, "OM-ZU"},
    {Tz::Asia_Nicosia, "CY"},
    {Tz::Asia_Nicosia, "CY-01"},
    {Tz::Asia_Nicosia, "CY-02"},
    {Tz::Asia_Nicosia, "CY-03"},
    {Tz::Asia_Nicosia, "CY-04"},
    {Tz::Asia_Nicosia, "CY-05"},
    {Tz::Asia_Nicosia, "CY-06"},
    {Tz::Asia_Novokuznetsk, "RU"},
    {Tz::Asia_Novokuznetsk, "RU-KEM"},
    {Tz::Asia_Novosibirsk, "RU"},
    {Tz::Asia_Novosibirsk, "RU-NVS"},
    {Tz::Asia_Omsk},
    {Tz::Asia_Omsk, "RU-OMS"},
    {Tz::Asia_Oral},
    {Tz::Asia_Oral, "KZ"},
    {Tz::Asia_Oral, "KZ-ZAP"},
    {Tz::Asia_Phnom_Penh},
    {Tz::Asia_Phnom_Penh, "KH"},
    {Tz::Asia_Phnom_Penh, "KH-1"},
    {Tz::Asia_Phnom_Penh, "KH-10"},
    {Tz::Asia_Phnom_Penh, "KH-11"},
    {Tz::Asia_Phnom_Penh, "KH-12"},
    {Tz::Asia_Phnom_Penh, "KH-13"},
    {Tz::Asia_Phnom_Penh, "KH-14"},
    {Tz::Asia_Phnom_Penh, "KH-15"},
    {Tz::Asia_Phnom_Penh, "KH-16"},
    {Tz::Asia_Phnom_Penh, "KH-17"},
    {Tz::Asia_Phnom_Penh, "KH-18"},
    {Tz::Asia_Phnom_Penh, "KH-19"},
    {Tz::Asia_Phnom_Penh, "KH-2"},
    {Tz::Asia_Phnom_Penh, "KH-20"},
    {Tz::Asia_Phnom_Penh, "KH-21"},
    {Tz::Asia_Phnom_Penh, "KH-22"},
    {Tz::Asia_Phnom_Penh, "KH-25"},
    {Tz::Asia_Phnom_Penh, "KH-3"},
    {Tz::Asia_Phnom_Penh, "KH-4"},
    {Tz::Asia_Phnom_Penh, "KH-5"},
    {Tz::Asia_Phnom_Penh, "KH-6"},
    {Tz::Asia_Phnom_Penh, "KH-7"},
    {Tz::Asia_Phnom_Penh, "KH-8"},
    {Tz::Asia_Phnom_Penh, "KH-9"},
    {Tz::Asia_Pontianak, "ID"},
    {Tz::Asia_Pyongyang},
    {Tz::Asia_Pyongyang, "KP"},
    {Tz::Asia_Pyongyang, "KP-01"},
    {Tz::Asia_Pyongyang, "KP-02"},
    {Tz::Asia_Pyongyang, "KP-03"},
    {Tz::Asia_Pyongyang, "KP-04"},
    {Tz::Asia_Pyongyang, "KP-05"},
    {Tz::Asia_Pyongyang, "KP-06"},
    {Tz::Asia_Pyongyang, "KP-07"},
    {Tz::Asia_Pyongyang, "KP-08"},
    {Tz::Asia_Pyongyang, "KP-09"},
    {Tz::Asia_Pyongyang, "KP-10"},
    {Tz::Asia_Pyongyang, "KP-13"},
    {Tz::Asia_Pyongyang, "KP-14"},
    {Tz::Asia_Qatar},
    {Tz::Asia_Qatar, "QA"},
    {Tz::Asia_Qatar, "QA-DA"},
    {Tz::Asia_Qatar, "QA-KH"},
    {Tz::Asia_Qatar, "QA-MS"},
    {Tz::Asia_Qatar, "QA-RA"},
    {Tz::Asia_Qatar, "QA-SH"},
    {Tz::Asia_Qatar, "QA-WA"},
    {Tz::Asia_Qatar, "QA-ZA"},
    {Tz::Asia_Qostanay, "KZ"},
    {Tz::Asia_Qostanay, "KZ-KUS"},
    {Tz::Asia_Qyzylorda},
    {Tz::Asia_Qyzylorda, "KZ"},
    {Tz::Asia_Qyzylorda, "KZ-KZY"},
    {Tz::Asia_Riyadh},
    {Tz::Asia_Riyadh, "SA"},
    {Tz::Asia_Riyadh, "SA-01"},
    {Tz::Asia_Riyadh, "SA-02"},
    {Tz::Asia_Riyadh, "SA-03"},
    {Tz::Asia_Riyadh, "SA-04"},
    {Tz::Asia_Riyadh, "SA-05"},
    {Tz::Asia_Riyadh, "SA-06"},
    {Tz::Asia_Riyadh, "SA-07"},
    {Tz::Asia_Riyadh, "SA-08"},
    {Tz::Asia_Riyadh, "SA-09"},
    {Tz::Asia_Riyadh, "SA-10"},
    {Tz::Asia_Riyadh, "SA-11"},
    {Tz::Asia_Riyadh, "SA-12"},
    {Tz::Asia_Riyadh, "SA-14"},
    {Tz::Asia_Sakhalin, "RU-SAK"},
    {Tz::Asia_Samarkand},
    {Tz::Asia_Samarkand, "UZ"},
    {Tz::Asia_Samarkand, "UZ-BU"},
    {Tz::Asia_Samarkand, "UZ-NW"},
    {Tz::Asia_Samarkand, "UZ-QA"},
    {Tz::Asia_Samarkand, "UZ-QR"},
    {Tz::Asia_Samarkand, "UZ-SA"},
    {Tz::Asia_Samarkand, "UZ-SU"},
    {Tz::Asia_Samarkand, "UZ-XO"},
    {Tz::Asia_Seoul},
    {Tz::Asia_Seoul, "KR"},
    {Tz::Asia_Seoul, "KR-11"},
    {Tz::Asia_Seoul, "KR-26"},
    {Tz::Asia_Seoul, "KR-27"},
    {Tz::Asia_Seoul, "KR-28"},
    {Tz::Asia_Seoul, "KR-29"},
    {Tz::Asia_Seoul, "KR-31"},
    {Tz::Asia_Seoul, "KR-41"},
    {Tz::Asia_Seoul, "KR-42"},
    {Tz::Asia_Seoul, "KR-43"},
    {Tz::Asia_Seoul, "KR-44"},
    {Tz::Asia_Seoul, "KR-45"},
    {Tz::Asia_Seoul, "KR-46"},
    {Tz::Asia_Seoul, "KR-47"},
    {Tz::Asia_Seoul, "KR-48"},
    {Tz::Asia_Seoul, "KR-49"},
    {Tz::Asia_Shanghai},
    {Tz::Asia_Shanghai, "CN"},
    {Tz::Asia_Shanghai, "CN-AH"},
    {Tz::Asia_Shanghai, "CN-BJ"},
    {Tz::Asia_Shanghai, "CN-CQ"},
    {Tz::Asia_Shanghai, "CN-FJ"},
    {Tz::Asia_Shanghai, "CN-GD"},
    {Tz::Asia_Shanghai, "CN-GS"},
    {Tz::Asia_Shanghai, "CN-GX"},
    {Tz::Asia_Shanghai, "CN-GZ"},
    {Tz::Asia_Shanghai, "CN-HA"},
    {Tz::Asia_Shanghai, "CN-HB"},
    {Tz::Asia_Shanghai, "CN-HE"},
    {Tz::Asia_Shanghai, "CN-HI"},
    {Tz::Asia_Shanghai, "CN-HL"},
    {Tz::Asia_Shanghai, "CN-HN"},
    {Tz::Asia_Shanghai, "CN-JL"},
    {Tz::Asia_Shanghai, "CN-JS"},
    {Tz::Asia_Shanghai, "CN-JX"},
    {Tz::Asia_Shanghai, "CN-LN"},
    {Tz::Asia_Shanghai, "CN-NM"},
    {Tz::Asia_Shanghai, "CN-NX"},
    {Tz::Asia_Shanghai, "CN-QH"},
    {Tz::Asia_Shanghai, "CN-SC"},
    {Tz::Asia_Shanghai, "CN-SD"},
    {Tz::Asia_Shanghai, "CN-SH"},
    {Tz::Asia_Shanghai, "CN-SN"},
    {Tz::Asia_Shanghai, "CN-SX"},
    {Tz::Asia_Shanghai, "CN-TJ"},
    {Tz::Asia_Shanghai, "CN-XZ"},
    {Tz::Asia_Shanghai, "CN-YN"},
    {Tz::Asia_Shanghai, "CN-ZJ"},
    {Tz::Asia_Singapore},
    {Tz::Asia_Singapore, "SG"},
    {Tz::Asia_Srednekolymsk, "RU"},
    {Tz::Asia_Srednekolymsk, "RU-SA"},
    {Tz::Asia_Srednekolymsk, "RU-SAK"},
    {Tz::Asia_Taipei},
    {Tz::Asia_Taipei, "TW"},
    {Tz::Asia_Taipei, "TW-CHA"},
    {Tz::Asia_Taipei, "TW-CYQ"},
    {Tz::Asia_Taipei, "TW-HSQ"},
    {Tz::Asia_Taipei, "TW-HSZ"},
    {Tz::Asia_Taipei, "TW-HUA"},
    {Tz::Asia_Taipei, "TW-ILA"},
    {Tz::Asia_Taipei, "TW-KEE"},
    {Tz::Asia_Taipei, "TW-KHH"},
    {Tz::Asia_Taipei, "TW-KIN"},
    {Tz::Asia_Taipei, "TW-MIA"},
    {Tz::Asia_Taipei, "TW-NAN"},
    {Tz::Asia_Taipei, "TW-NWT"},
    {Tz::Asia_Taipei, "TW-PEN"},
    {Tz::Asia_Taipei, "TW-PIF"},
    {Tz::Asia_Taipei, "TW-TAO"},
    {Tz::Asia_Taipei, "TW-TNN"},
    {Tz::Asia_Taipei, "TW-TTT"},
    {Tz::Asia_Taipei, "TW-TXG"},
    {Tz::Asia_Taipei, "TW-YUN"},
    {Tz::Asia_Tashkent},
    {Tz::Asia_Tashkent, "UZ"},
    {Tz::Asia_Tashkent, "UZ-AN"},
    {Tz::Asia_Tashkent, "UZ-FA"},
    {Tz::Asia_Tashkent, "UZ-JI"},
    {Tz::Asia_Tashkent, "UZ-NG"},
    {Tz::Asia_Tashkent, "UZ-SI"},
    {Tz::Asia_Tashkent, "UZ-TO"},
    {Tz::Asia_Tbilisi},
    {Tz::Asia_Tbilisi, "GE"},
    {Tz::Asia_Tbilisi, "GE-AJ"},
    {Tz::Asia_Tbilisi, "GE-GU"},
    {Tz::Asia_Tbilisi, "GE-IM"},
    {Tz::Asia_Tbilisi, "GE-KA"},
    {Tz::Asia_Tbilisi, "GE-KK"},
    {Tz::Asia_Tbilisi, "GE-MM"},
    {Tz::Asia_Tbilisi, "GE-RL"},
    {Tz::Asia_Tbilisi, "GE-SJ"},
    {Tz::Asia_Tbilisi, "GE-SK"},
    {Tz::Asia_Tbilisi, "GE-SZ"},
    {Tz::Asia_Tehran},
    {Tz::Asia_Tehran, "IR"},
    {Tz::Asia_Tehran, "IR-00"},
    {Tz::Asia_Tehran, "IR-01"},
    {Tz::Asia_Tehran, "IR-02"},
    {Tz::Asia_Tehran, "IR-03"},
    {Tz::Asia_Tehran, "IR-04"},
    {Tz::Asia_Tehran, "IR-05"},
    {Tz::Asia_Tehran, "IR-06"},
    {Tz::Asia_Tehran, "IR-07"},
    {Tz::Asia_Tehran, "IR-08"},
    {Tz::Asia_Tehran, "IR-09"},
    {Tz::Asia_Tehran, "IR-10"},
    {Tz::Asia_Tehran, "IR-11"},
    {Tz::Asia_Tehran, "IR-12"},
    {Tz::Asia_Tehran, "IR-13"},
    {Tz::Asia_Tehran, "IR-14"},
    {Tz::Asia_Tehran, "IR-15"},
    {Tz::Asia_Tehran, "IR-16"},
    {Tz::Asia_Tehran, "IR-17"},
    {Tz::Asia_Tehran, "IR-18"},
    {Tz::Asia_Tehran, "IR-19"},
    {Tz::Asia_Tehran, "IR-20"},
    {Tz::Asia_Tehran, "IR-21"},
    {Tz::Asia_Tehran, "IR-22"},
    {Tz::Asia_Tehran, "IR-23"},
    {Tz::Asia_Tehran, "IR-24"},
    {Tz::Asia_Tehran, "IR-25"},
    {Tz::Asia_Tehran, "IR-26"},
    {Tz::Asia_Tehran, "IR-27"},
    {Tz::Asia_Tehran, "IR-28"},
    {Tz::Asia_Tehran, "IR-29"},
    {Tz::Asia_Tehran, "IR-30"},
    {Tz::Asia_Thimphu, "BT"},
    {Tz::Asia_Thimphu, "BT-11"},
    {Tz::Asia_Thimphu, "BT-12"},
    {Tz::Asia_Thimphu, "BT-13"},
    {Tz::Asia_Thimphu, "BT-14"},
    {Tz::Asia_Thimphu, "BT-15"},
    {Tz::Asia_Thimphu, "BT-22"},
    {Tz::Asia_Thimphu, "BT-23"},
    {Tz::Asia_Thimphu, "BT-24"},
    {Tz::Asia_Thimphu, "BT-31"},
    {Tz::Asia_Thimphu, "BT-32"},
    {Tz::Asia_Thimphu, "BT-33"},
    {Tz::Asia_Thimphu, "BT-34"},
    {Tz::Asia_Thimphu, "BT-41"},
    {Tz::Asia_Thimphu, "BT-42"},
    {Tz::Asia_Thimphu, "BT-43"},
    {Tz::Asia_Thimphu, "BT-44"},
    {Tz::Asia_Thimphu, "BT-45"},
    {Tz::Asia_Thimphu, "BT-GA"},
    {Tz::Asia_Thimphu, "BT-TY"},
    {Tz::Asia_Tokyo},
    {Tz::Asia_Tokyo, "JP"},
    {Tz::Asia_Tokyo, "JP-01"},
    {Tz::Asia_Tokyo, "JP-02"},
    {Tz::Asia_Tokyo, "JP-03"},
    {Tz::Asia_Tokyo, "JP-04"},
    {Tz::Asia_Tokyo, "JP-05"},
    {Tz::Asia_Tokyo, "JP-06"},
    {Tz::Asia_Tokyo, "JP-07"},
    {Tz::Asia_Tokyo, "JP-08"},
    {Tz::Asia_Tokyo, "JP-09"},
    {Tz::Asia_Tokyo, "JP-10"},
    {Tz::Asia_Tokyo, "JP-11"},
    {Tz::Asia_Tokyo, "JP-12"},
    {Tz::Asia_Tokyo, "JP-13"},
    {Tz::Asia_Tokyo, "JP-14"},
    {Tz::Asia_Tokyo, "JP-15"},
    {Tz::Asia_Tokyo, "JP-16"},
    {Tz::Asia_Tokyo, "JP-17"},
    {Tz::Asia_Tokyo, "JP-18"},
    {Tz::Asia_Tokyo, "JP-19"},
    {Tz::Asia_Tokyo, "JP-20"},
    {Tz::Asia_Tokyo, "JP-21"},
    {Tz::Asia_Tokyo, "JP-22"},
    {Tz::Asia_Tokyo, "JP-23"},
    {Tz::Asia_Tokyo, "JP-24"},
    {Tz::Asia_Tokyo, "JP-25"},
    {Tz::Asia_Tokyo, "JP-26"},
    {Tz::Asia_Tokyo, "JP-27"},
    {Tz::Asia_Tokyo, "JP-28"},
    {Tz::Asia_Tokyo, "JP-29"},
    {Tz::Asia_Tokyo, "JP-30"},
    {Tz::Asia_Tokyo, "JP-31"},
    {Tz::Asia_Tokyo, "JP-32"},
    {Tz::Asia_Tokyo, "JP-33"},
    {Tz::Asia_Tokyo, "JP-34"},
    {Tz::Asia_Tokyo, "JP-35"},
    {Tz::Asia_Tokyo, "JP-36"},
    {Tz::Asia_Tokyo, "JP-37"},
    {Tz::Asia_Tokyo, "JP-38"},
    {Tz::Asia_Tokyo, "JP-39"},
    {Tz::Asia_Tokyo, "JP-40"},
    {Tz::Asia_Tokyo, "JP-41"},
    {Tz::Asia_Tokyo, "JP-42"},
    {Tz::Asia_Tokyo, "JP-43"},
    {Tz::Asia_Tokyo, "JP-44"},
    {Tz::Asia_Tokyo, "JP-45"},
    {Tz::Asia_Tokyo, "JP-46"},
    {Tz::Asia_Tokyo, "JP-47"},
    {Tz::Asia_Tomsk, "RU"},
    {Tz::Asia_Tomsk, "RU-TOM"},
    {Tz::Asia_Ulaanbaatar},
    {Tz::Asia_Ulaanbaatar, "MN"},
    {Tz::Asia_Ulaanbaatar, "MN-035"},
    {Tz::Asia_Ulaanbaatar, "MN-037"},
    {Tz::Asia_Ulaanbaatar, "MN-039"},
    {Tz::Asia_Ulaanbaatar, "MN-041"},
    {Tz::Asia_Ulaanbaatar, "MN-047"},
    {Tz::Asia_Ulaanbaatar, "MN-049"},
    {Tz::Asia_Ulaanbaatar, "MN-053"},
    {Tz::Asia_Ulaanbaatar, "MN-055"},
    {Tz::Asia_Ulaanbaatar, "MN-059"},
    {Tz::Asia_Ulaanbaatar, "MN-063"},
    {Tz::Asia_Ulaanbaatar, "MN-064"},
    {Tz::Asia_Ulaanbaatar, "MN-067"},
    {Tz::Asia_Ulaanbaatar, "MN-069"},
    {Tz::Asia_Ulaanbaatar, "MN-073"},
    {Tz::Asia_Ulaanbaatar, "MN-1"},
    {Tz::Asia_Ust_Nera, "RU"},
    {Tz::Asia_Ust_Nera, "RU-SA"},
    {Tz::Asia_Ust_Nera, "RU-SAK"},
    {Tz::Asia_Vientiane},
    {Tz::Asia_Vientiane, "LA"},
    {Tz::Asia_Vientiane, "LA-AT"},
    {Tz::Asia_Vientiane, "LA-BK"},
    {Tz::Asia_Vientiane, "LA-BL"},
    {Tz::Asia_Vientiane, "LA-CH"},
    {Tz::Asia_Vientiane, "LA-HO"},
    {Tz::Asia_Vientiane, "LA-KH"},
    {Tz::Asia_Vientiane, "LA-LM"},
    {Tz::Asia_Vientiane, "LA-LP"},
    {Tz::Asia_Vientiane, "LA-OU"},
    {Tz::Asia_Vientiane, "LA-PH"},
    {Tz::Asia_Vientiane, "LA-SL"},
    {Tz::Asia_Vientiane, "LA-SV"},
    {Tz::Asia_Vientiane, "LA-VI"},
    {Tz::Asia_Vientiane, "LA-VT"},
    {Tz::Asia_Vientiane, "LA-XA"},
    {Tz::Asia_Vientiane, "LA-XE"},
    {Tz::Asia_Vientiane, "LA-XI"},
    {Tz::Asia_Vientiane, "LA-XS"},
    {Tz::Asia_Vladivostok, "RU"},
    {Tz::Asia_Vladivostok, "RU-KHA"},
    {Tz::Asia_Vladivostok, "RU-PRI"},
    {Tz::Asia_Vladivostok, "RU-SA"},
    {Tz::Asia_Vladivostok, "RU-YEV"},
    {Tz::Asia_Yakutsk, "RU"},
    {Tz::Asia_Yakutsk, "RU-AMU"},
    {Tz::Asia_Yakutsk, "RU-SA"},
    {Tz::Asia_Yangon, "MM"},
    {Tz::Asia_Yangon, "MM-01"},
    {Tz::Asia_Yangon, "MM-02"},
    {Tz::Asia_Yangon, "MM-03"},
    {Tz::Asia_Yangon, "MM-04"},
    {Tz::Asia_Yangon, "MM-05"},
    {Tz::Asia_Yangon, "MM-06"},
    {Tz::Asia_Yangon, "MM-07"},
    {Tz::Asia_Yangon, "MM-11"},
    {Tz::Asia_Yangon, "MM-12"},
    {Tz::Asia_Yangon, "MM-13"},
    {Tz::Asia_Yangon, "MM-14"},
    {Tz::Asia_Yangon, "MM-15"},
    {Tz::Asia_Yangon, "MM-16"},
    {Tz::Asia_Yangon, "MM-17"},
    {Tz::Asia_Yangon, "MM-18"},
    {Tz::Asia_Yekaterinburg},
    {Tz::Asia_Yekaterinburg, "RU"},
    {Tz::Asia_Yekaterinburg, "RU-BA"},
    {Tz::Asia_Yekaterinburg, "RU-CHE"},
    {Tz::Asia_Yekaterinburg, "RU-KGN"},
    {Tz::Asia_Yekaterinburg, "RU-KHM"},
    {Tz::Asia_Yekaterinburg, "RU-ORE"},
    {Tz::Asia_Yekaterinburg, "RU-PER"},
    {Tz::Asia_Yekaterinburg, "RU-SVE"},
    {Tz::Asia_Yekaterinburg, "RU-TYU"},
    {Tz::Asia_Yekaterinburg, "RU-YAN"},
    {Tz::Asia_Yerevan},
    {Tz::Asia_Yerevan, "AM"},
    {Tz::Asia_Yerevan, "AM-AG"},
    {Tz::Asia_Yerevan, "AM-AR"},
    {Tz::Asia_Yerevan, "AM-AV"},
    {Tz::Asia_Yerevan, "AM-GR"},
    {Tz::Asia_Yerevan, "AM-KT"},
    {Tz::Asia_Yerevan, "AM-LO"},
    {Tz::Asia_Yerevan, "AM-SH"},
    {Tz::Asia_Yerevan, "AM-SU"},
    {Tz::Asia_Yerevan, "AM-TV"},
    {Tz::Asia_Yerevan, "AM-VD"},
    {Tz::Atlantic_Azores, "PT-20"},
    {Tz::Atlantic_Bermuda, "BM"},
    {Tz::Atlantic_Canary, "ES"},
    {Tz::Atlantic_Canary, "ES-CN"},
    {Tz::Atlantic_Cape_Verde, "CV"},
    {Tz::Atlantic_Cape_Verde, "CV-B"},
    {Tz::Atlantic_Faroe, "FO"},
    {Tz::Atlantic_Madeira, "PT-30"},
    {Tz::Atlantic_Reykjavik, "IS"},
    {Tz::Atlantic_Reykjavik, "IS-1"},
    {Tz::Atlantic_Reykjavik, "IS-2"},
    {Tz::Atlantic_Reykjavik, "IS-3"},
    {Tz::Atlantic_Reykjavik, "IS-4"},
    {Tz::Atlantic_Reykjavik, "IS-5"},
    {Tz::Atlantic_Reykjavik, "IS-6"},
    {Tz::Atlantic_Reykjavik, "IS-7"},
    {Tz::Atlantic_Reykjavik, "IS-8"},
    {Tz::Atlantic_South_Georgia, "GS"},
    {Tz::Atlantic_St_Helena, "SH-AC"},
    {Tz::Atlantic_St_Helena, "SH-HL"},
    {Tz::Atlantic_St_Helena, "SH-TA"},
    {Tz::Atlantic_Stanley, "FK"},
    {Tz::Australia_Adelaide, "AU-SA"},
    {Tz::Australia_Brisbane, "AU-QLD"},
    {Tz::Australia_Broken_Hill, "AU"},
    {Tz::Australia_Broken_Hill, "AU-NSW"},
    {Tz::Australia_Currie, "AU"},
    {Tz::Australia_Currie, "AU-TAS"},
    {Tz::Australia_Darwin, "AU-NT"},
    {Tz::Australia_Eucla, "AU-WA"},
    {Tz::Australia_Hobart, "AU-TAS"},
    {Tz::Australia_Lindeman, "AU-QLD"},
    {Tz::Australia_Lord_Howe, "AU-NSW"},
    {Tz::Australia_Melbourne, "AU"},
    {Tz::Australia_Melbourne, "AU-VIC"},
    {Tz::Australia_Perth, "AU-WA"},
    {Tz::Australia_Sydney, "AU"},
    {Tz::Australia_Sydney, "AU-ACT"},
    {Tz::Australia_Sydney, "AU-NSW"},
    {Tz::Europe_Amsterdam},
    {Tz::Europe_Amsterdam, "NL"},
    {Tz::Europe_Amsterdam, "NL-DR"},
    {Tz::Europe_Amsterdam, "NL-FL"},
    {Tz::Europe_Amsterdam, "NL-FR"},
    {Tz::Europe_Amsterdam, "NL-GE"},
    {Tz::Europe_Amsterdam, "NL-GR"},
    {Tz::Europe_Amsterdam, "NL-LI"},
    {Tz::Europe_Amsterdam, "NL-NB"},
    {Tz::Europe_Amsterdam, "NL-NH"},
    {Tz::Europe_Amsterdam, "NL-OV"},
    {Tz::Europe_Amsterdam, "NL-UT"},
    {Tz::Europe_Amsterdam, "NL-ZE"},
    {Tz::Europe_Amsterdam, "NL-ZH"},
    {Tz::Europe_Andorra},
    {Tz::Europe_Astrakhan, "RU"},
    {Tz::Europe_Astrakhan, "RU-AST"},
    {Tz::Europe_Athens},
    {Tz::Europe_Athens, "GR"},
    {Tz::Europe_Athens, "GR-69"},
    {Tz::Europe_Athens, "GR-A"},
    {Tz::Europe_Athens, "GR-B"},
    {Tz::Europe_Athens, "GR-C"},
    {Tz::Europe_Athens, "GR-D"},
    {Tz::Europe_Athens, "GR-E"},
    {Tz::Europe_Athens, "GR-F"},
    {Tz::Europe_Athens, "GR-G"},
    {Tz::Europe_Athens, "GR-H"},
    {Tz::Europe_Athens, "GR-I"},
    {Tz::Europe_Athens, "GR-J"},
    {Tz::Europe_Athens, "GR-K"},
    {Tz::Europe_Athens, "GR-L"},
    {Tz::Europe_Athens, "GR-M"},
    {Tz::Europe_Belgrade},
    {Tz::Europe_Belgrade, "RS"},
    {Tz::Europe_Belgrade, "RS-00"},
    {Tz::Europe_Belgrade, "RS-08"},
    {Tz::Europe_Belgrade, "RS-09"},
    {Tz::Europe_Belgrade, "RS-10"},
    {Tz::Europe_Belgrade, "RS-11"},
    {Tz::Europe_Belgrade, "RS-12"},
    {Tz::Europe_Belgrade, "RS-13"},
    {Tz::Europe_Belgrade, "RS-14"},
    {Tz::Europe_Belgrade, "RS-15"},
    {Tz::Europe_Belgrade, "RS-16"},
    {Tz::Europe_Belgrade, "RS-17"},
    {Tz::Europe_Belgrade, "RS-18"},
    {Tz::Europe_Belgrade, "RS-19"},
    {Tz::Europe_Belgrade, "RS-20"},
    {Tz::Europe_Belgrade, "RS-21"},
    {Tz::Europe_Belgrade, "RS-22"},
    {Tz::Europe_Belgrade, "RS-23"},
    {Tz::Europe_Belgrade, "RS-24"},
    {Tz::Europe_Belgrade, "RS-KO"},
    {Tz::Europe_Berlin},
    {Tz::Europe_Berlin, "DE"},
    {Tz::Europe_Berlin, "DE-BB"},
    {Tz::Europe_Berlin, "DE-BE"},
    {Tz::Europe_Berlin, "DE-BW"},
    {Tz::Europe_Berlin, "DE-BY"},
    {Tz::Europe_Berlin, "DE-HB"},
    {Tz::Europe_Berlin, "DE-HE"},
    {Tz::Europe_Berlin, "DE-HH"},
    {Tz::Europe_Berlin, "DE-MV"},
    {Tz::Europe_Berlin, "DE-NI"},
    {Tz::Europe_Berlin, "DE-NW"},
    {Tz::Europe_Berlin, "DE-RP"},
    {Tz::Europe_Berlin, "DE-SH"},
    {Tz::Europe_Berlin, "DE-SL"},
    {Tz::Europe_Berlin, "DE-SN"},
    {Tz::Europe_Berlin, "DE-ST"},
    {Tz::Europe_Berlin, "DE-TH"},
    {Tz::Europe_Bratislava},
    {Tz::Europe_Bratislava, "SK"},
    {Tz::Europe_Bratislava, "SK-BC"},
    {Tz::Europe_Bratislava, "SK-BL"},
    {Tz::Europe_Bratislava, "SK-ZI"},
    {Tz::Europe_Brussels},
    {Tz::Europe_Brussels, "BE"},
    {Tz::Europe_Brussels, "BE-VLG"},
    {Tz::Europe_Brussels, "BE-WAL"},
    {Tz::Europe_Bucharest},
    {Tz::Europe_Bucharest, "RO"},
    {Tz::Europe_Bucharest, "RO-AB"},
    {Tz::Europe_Bucharest, "RO-AG"},
    {Tz::Europe_Bucharest, "RO-AR"},
    {Tz::Europe_Bucharest, "RO-BC"},
    {Tz::Europe_Bucharest, "RO-BH"},
    {Tz::Europe_Bucharest, "RO-BN"},
    {Tz::Europe_Bucharest, "RO-BR"},
    {Tz::Europe_Bucharest, "RO-BT"},
    {Tz::Europe_Bucharest, "RO-BV"},
    {Tz::Europe_Bucharest, "RO-BZ"},
    {Tz::Europe_Bucharest, "RO-CJ"},
    {Tz::Europe_Bucharest, "RO-CL"},
    {Tz::Europe_Bucharest, "RO-CS"},
    {Tz::Europe_Bucharest, "RO-CT"},
    {Tz::Europe_Bucharest, "RO-CV"},
    {Tz::Europe_Bucharest, "RO-DB"},
    {Tz::Europe_Bucharest, "RO-DJ"},
    {Tz::Europe_Bucharest, "RO-GJ"},
    {Tz::Europe_Bucharest, "RO-GL"},
    {Tz::Europe_Bucharest, "RO-GR"},
    {Tz::Europe_Bucharest, "RO-HD"},
    {Tz::Europe_Bucharest, "RO-HR"},
    {Tz::Europe_Bucharest, "RO-IF"},
    {Tz::Europe_Bucharest, "RO-IL"},
    {Tz::Europe_Bucharest, "RO-IS"},
    {Tz::Europe_Bucharest, "RO-MH"},
    {Tz::Europe_Bucharest, "RO-MM"},
    {Tz::Europe_Bucharest, "RO-MS"},
    {Tz::Europe_Bucharest, "RO-NT"},
    {Tz::Europe_Bucharest, "RO-OT"},
    {Tz::Europe_Bucharest, "RO-PH"},
    {Tz::Europe_Bucharest, "RO-SB"},
    {Tz::Europe_Bucharest, "RO-SJ"},
    {Tz::Europe_Bucharest, "RO-SM"},
    {Tz::Europe_Bucharest, "RO-SV"},
    {Tz::Europe_Bucharest, "RO-TL"},
    {Tz::Europe_Bucharest, "RO-TM"},
    {Tz::Europe_Bucharest, "RO-TR"},
    {Tz::Europe_Bucharest, "RO-VL"},
    {Tz::Europe_Bucharest, "RO-VN"},
    {Tz::Europe_Bucharest, "RO-VS"},
    {Tz::Europe_Budapest},
    {Tz::Europe_Budapest, "HU"},
    {Tz::Europe_Budapest, "HU-BA"},
    {Tz::Europe_Budapest, "HU-BE"},
    {Tz::Europe_Budapest, "HU-BK"},
    {Tz::Europe_Budapest, "HU-BU"},
    {Tz::Europe_Budapest, "HU-BZ"},
    {Tz::Europe_Budapest, "HU-CS"},
    {Tz::Europe_Budapest, "HU-FE"},
    {Tz::Europe_Budapest, "HU-GS"},
    {Tz::Europe_Budapest, "HU-HB"},
    {Tz::Europe_Budapest, "HU-HE"},
    {Tz::Europe_Budapest, "HU-JN"},
    {Tz::Europe_Budapest, "HU-KE"},
    {Tz::Europe_Budapest, "HU-NO"},
    {Tz::Europe_Budapest, "HU-PE"},
    {Tz::Europe_Budapest, "HU-SO"},
    {Tz::Europe_Budapest, "HU-SZ"},
    {Tz::Europe_Budapest, "HU-TO"},
    {Tz::Europe_Budapest, "HU-VA"},
    {Tz::Europe_Budapest, "HU-VE"},
    {Tz::Europe_Budapest, "HU-ZA"},
    {Tz::Europe_Chisinau},
    {Tz::Europe_Chisinau, "MD"},
    {Tz::Europe_Chisinau, "MD-AN"},
    {Tz::Europe_Chisinau, "MD-BR"},
    {Tz::Europe_Chisinau, "MD-CA"},
    {Tz::Europe_Chisinau, "MD-CL"},
    {Tz::Europe_Chisinau, "MD-CM"},
    {Tz::Europe_Chisinau, "MD-CR"},
    {Tz::Europe_Chisinau, "MD-CS"},
    {Tz::Europe_Chisinau, "MD-CT"},
    {Tz::Europe_Chisinau, "MD-DO"},
    {Tz::Europe_Chisinau, "MD-DR"},
    {Tz::Europe_Chisinau, "MD-ED"},
    {Tz::Europe_Chisinau, "MD-FA"},
    {Tz::Europe_Chisinau, "MD-FL"},
    {Tz::Europe_Chisinau, "MD-GA"},
    {Tz::Europe_Chisinau, "MD-GL"},
    {Tz::Europe_Chisinau, "MD-HI"},
    {Tz::Europe_Chisinau, "MD-IA"},
    {Tz::Europe_Chisinau, "MD-LE"},
    {Tz::Europe_Chisinau, "MD-OC"},
    {Tz::Europe_Chisinau, "MD-OR"},
    {Tz::Europe_Chisinau, "MD-RI"},
    {Tz::Europe_Chisinau, "MD-SD"},
    {Tz::Europe_Chisinau, "MD-SI"},
    {Tz::Europe_Chisinau, "MD-SN"},
    {Tz::Europe_Chisinau, "MD-SO"},
    {Tz::Europe_Chisinau, "MD-ST"},
    {Tz::Europe_Chisinau, "MD-SV"},
    {Tz::Europe_Chisinau, "MD-TE"},
    {Tz::Europe_Chisinau, "MD-UN"},
    {Tz::Europe_Copenhagen},
    {Tz::Europe_Copenhagen, "DK"},
    {Tz::Europe_Copenhagen, "DK-81"},
    {Tz::Europe_Copenhagen, "DK-82"},
    {Tz::Europe_Copenhagen, "DK-83"},
    {Tz::Europe_Copenhagen, "DK-84"},
    {Tz::Europe_Copenhagen, "DK-85"},
    {Tz::Europe_Dublin, "IE"},
    {Tz::Europe_Dublin, "IE-C"},
    {Tz::Europe_Dublin, "IE-L"},
    {Tz::Europe_Dublin, "IE-M"},
    {Tz::Europe_Guernsey},
    {Tz::Europe_Guernsey, "GG"},
    {Tz::Europe_Helsinki, "FI"},
    {Tz::Europe_Helsinki, "FI-01"},
    {Tz::Europe_Helsinki, "FI-02"},
    {Tz::Europe_Helsinki, "FI-03"},
    {Tz::Europe_Helsinki, "FI-04"},
    {Tz::Europe_Helsinki, "FI-05"},
    {Tz::Europe_Helsinki, "FI-06"},
    {Tz::Europe_Helsinki, "FI-07"},
    {Tz::Europe_Helsinki, "FI-08"},
    {Tz::Europe_Helsinki, "FI-09"},
    {Tz::Europe_Helsinki, "FI-10"},
    {Tz::Europe_Helsinki, "FI-11"},
    {Tz::Europe_Helsinki, "FI-12"},
    {Tz::Europe_Helsinki, "FI-13"},
    {Tz::Europe_Helsinki, "FI-14"},
    {Tz::Europe_Helsinki, "FI-15"},
    {Tz::Europe_Helsinki, "FI-16"},
    {Tz::Europe_Helsinki, "FI-17"},
    {Tz::Europe_Helsinki, "FI-18"},
    {Tz::Europe_Helsinki, "FI-19"},
    {Tz::Europe_Isle_of_Man, "IM"},
    {Tz::Europe_Istanbul},
    {Tz::Europe_Istanbul, "TR"},
    {Tz::Europe_Istanbul, "TR-01"},
    {Tz::Europe_Istanbul, "TR-02"},
    {Tz::Europe_Istanbul, "TR-03"},
    {Tz::Europe_Istanbul, "TR-04"},
    {Tz::Europe_Istanbul, "TR-05"},
    {Tz::Europe_Istanbul, "TR-06"},
    {Tz::Europe_Istanbul, "TR-07"},
    {Tz::Europe_Istanbul, "TR-08"},
    {Tz::Europe_Istanbul, "TR-09"},
    {Tz::Europe_Istanbul, "TR-10"},
    {Tz::Europe_Istanbul, "TR-11"},
    {Tz::Europe_Istanbul, "TR-12"},
    {Tz::Europe_Istanbul, "TR-13"},
    {Tz::Europe_Istanbul, "TR-14"},
    {Tz::Europe_Istanbul, "TR-15"},
    {Tz::Europe_Istanbul, "TR-16"},
    {Tz::Europe_Istanbul, "TR-17"},
    {Tz::Europe_Istanbul, "TR-18"},
    {Tz::Europe_Istanbul, "TR-19"},
    {Tz::Europe_Istanbul, "TR-20"},
    {Tz::Europe_Istanbul, "TR-21"},
    {Tz::Europe_Istanbul, "TR-22"},
    {Tz::Europe_Istanbul, "TR-23"},
    {Tz::Europe_Istanbul, "TR-24"},
    {Tz::Europe_Istanbul, "TR-25"},
    {Tz::Europe_Istanbul, "TR-26"},
    {Tz::Europe_Istanbul, "TR-27"},
    {Tz::Europe_Istanbul, "TR-28"},
    {Tz::Europe_Istanbul, "TR-29"},
    {Tz::Europe_Istanbul, "TR-30"},
    {Tz::Europe_Istanbul, "TR-31"},
    {Tz::Europe_Istanbul, "TR-32"},
    {Tz::Europe_Istanbul, "TR-33"},
    {Tz::Europe_Istanbul, "TR-34"},
    {Tz::Europe_Istanbul, "TR-35"},
    {Tz::Europe_Istanbul, "TR-36"},
    {Tz::Europe_Istanbul, "TR-37"},
    {Tz::Europe_Istanbul, "TR-38"},
    {Tz::Europe_Istanbul, "TR-39"},
    {Tz::Europe_Istanbul, "TR-40"},
    {Tz::Europe_Istanbul, "TR-41"},
    {Tz::Europe_Istanbul, "TR-42"},
    {Tz::Europe_Istanbul, "TR-43"},
    {Tz::Europe_Istanbul, "TR-44"},
    {Tz::Europe_Istanbul, "TR-45"},
    {Tz::Europe_Istanbul, "TR-46"},
    {Tz::Europe_Istanbul, "TR-47"},
    {Tz::Europe_Istanbul, "TR-48"},
    {Tz::Europe_Istanbul, "TR-49"},
    {Tz::Europe_Istanbul, "TR-50"},
    {Tz::Europe_Istanbul, "TR-51"},
    {Tz::Europe_Istanbul, "TR-52"},
    {Tz::Europe_Istanbul, "TR-53"},
    {Tz::Europe_Istanbul, "TR-54"},
    {Tz::Europe_Istanbul, "TR-55"},
    {Tz::Europe_Istanbul, "TR-56"},
    {Tz::Europe_Istanbul, "TR-57"},
    {Tz::Europe_Istanbul, "TR-58"},
    {Tz::Europe_Istanbul, "TR-59"},
    {Tz::Europe_Istanbul, "TR-60"},
    {Tz::Europe_Istanbul, "TR-61"},
    {Tz::Europe_Istanbul, "TR-62"},
    {Tz::Europe_Istanbul, "TR-63"},
    {Tz::Europe_Istanbul, "TR-64"},
    {Tz::Europe_Istanbul, "TR-65"},
    {Tz::Europe_Istanbul, "TR-66"},
    {Tz::Europe_Istanbul, "TR-67"},
    {Tz::Europe_Istanbul, "TR-68"},
    {Tz::Europe_Istanbul, "TR-69"},
    {Tz::Europe_Istanbul, "TR-70"},
    {Tz::Europe_Istanbul, "TR-71"},
    {Tz::Europe_Istanbul, "TR-72"},
    {Tz::Europe_Istanbul, "TR-73"},
    {Tz::Europe_Istanbul, "TR-74"},
    {Tz::Europe_Istanbul, "TR-75"},
    {Tz::Europe_Istanbul, "TR-76"},
    {Tz::Europe_Istanbul, "TR-77"},
    {Tz::Europe_Istanbul, "TR-78"},
    {Tz::Europe_Istanbul, "TR-79"},
    {Tz::Europe_Istanbul, "TR-80"},
    {Tz::Europe_Istanbul, "TR-81"},
    {Tz::Europe_Jersey},
    {Tz::Europe_Jersey, "JE"},
    {Tz::Europe_Kaliningrad, "RU-KGD"},
    {Tz::Europe_Kiev},
    {Tz::Europe_Kiev, "UA"},
    {Tz::Europe_Kiev, "UA-05"},
    {Tz::Europe_Kiev, "UA-07"},
    {Tz::Europe_Kiev, "UA-09"},
    {Tz::Europe_Kiev, "UA-12"},
    {Tz::Europe_Kiev, "UA-14"},
    {Tz::Europe_Kiev, "UA-18"},
    {Tz::Europe_Kiev, "UA-26"},
    {Tz::Europe_Kiev, "UA-30"},
    {Tz::Europe_Kiev, "UA-32"},
    {Tz::Europe_Kiev, "UA-35"},
    {Tz::Europe_Kiev, "UA-46"},
    {Tz::Europe_Kiev, "UA-48"},
    {Tz::Europe_Kiev, "UA-51"},
    {Tz::Europe_Kiev, "UA-53"},
    {Tz::Europe_Kiev, "UA-56"},
    {Tz::Europe_Kiev, "UA-59"},
    {Tz::Europe_Kiev, "UA-61"},
    {Tz::Europe_Kiev, "UA-63"},
    {Tz::Europe_Kiev, "UA-65"},
    {Tz::Europe_Kiev, "UA-68"},
    {Tz::Europe_Kiev, "UA-71"},
    {Tz::Europe_Kiev, "UA-74"},
    {Tz::Europe_Kiev, "UA-77"},
    {Tz::Europe_Kirov, "RU-KIR"},
    {Tz::Europe_Lisbon, "PT"},
    {Tz::Europe_Lisbon, "PT-01"},
    {Tz::Europe_Lisbon, "PT-02"},
    {Tz::Europe_Lisbon, "PT-03"},
    {Tz::Europe_Lisbon, "PT-04"},
    {Tz::Europe_Lisbon, "PT-05"},
    {Tz::Europe_Lisbon, "PT-06"},
    {Tz::Europe_Lisbon, "PT-07"},
    {Tz::Europe_Lisbon, "PT-08"},
    {Tz::Europe_Lisbon, "PT-09"},
    {Tz::Europe_Lisbon, "PT-10"},
    {Tz::Europe_Lisbon, "PT-11"},
    {Tz::Europe_Lisbon, "PT-12"},
    {Tz::Europe_Lisbon, "PT-13"},
    {Tz::Europe_Lisbon, "PT-14"},
    {Tz::Europe_Lisbon, "PT-15"},
    {Tz::Europe_Lisbon, "PT-16"},
    {Tz::Europe_Lisbon, "PT-17"},
    {Tz::Europe_Lisbon, "PT-18"},
    {Tz::Europe_Ljubljana},
    {Tz::Europe_Ljubljana, "SI"},
    {Tz::Europe_Ljubljana, "SI-006"},
    {Tz::Europe_Ljubljana, "SI-017"},
    {Tz::Europe_Ljubljana, "SI-038"},
    {Tz::Europe_Ljubljana, "SI-048"},
    {Tz::Europe_Ljubljana, "SI-050"},
    {Tz::Europe_Ljubljana, "SI-053"},
    {Tz::Europe_Ljubljana, "SI-085"},
    {Tz::Europe_Ljubljana, "SI-094"},
    {Tz::Europe_Ljubljana, "SI-128"},
    {Tz::Europe_London},
    {Tz::Europe_London, "GB"},
    {Tz::Europe_London, "GB-ENG"},
    {Tz::Europe_London, "GB-NIR"},
    {Tz::Europe_London, "GB-SCT"},
    {Tz::Europe_London, "GB-WLS"},
    {Tz::Europe_Luxembourg},
    {Tz::Europe_Luxembourg, "LU"},
    {Tz::Europe_Luxembourg, "LU-RD"},
    {Tz::Europe_Madrid},
    {Tz::Europe_Madrid, "ES"},
    {Tz::Europe_Madrid, "ES-AN"},
    {Tz::Europe_Madrid, "ES-AR"},
    {Tz::Europe_Madrid, "ES-AS"},
    {Tz::Europe_Madrid, "ES-CB"},
    {Tz::Europe_Madrid, "ES-CL"},
    {Tz::Europe_Madrid, "ES-CM"},
    {Tz::Europe_Madrid, "ES-CT"},
    {Tz::Europe_Madrid, "ES-EX"},
    {Tz::Europe_Madrid, "ES-GA"},
    {Tz::Europe_Madrid, "ES-IB"},
    {Tz::Europe_Madrid, "ES-MC"},
    {Tz::Europe_Madrid, "ES-MD"},
    {Tz::Europe_Madrid, "ES-NC"},
    {Tz::Europe_Madrid, "ES-PV"},
    {Tz::Europe_Madrid, "ES-RI"},
    {Tz::Europe_Madrid, "ES-VC"},
    {Tz::Europe_Malta, "MT"},
    {Tz::Europe_Minsk, "BY"},
    {Tz::Europe_Minsk, "BY-BR"},
    {Tz::Europe_Minsk, "BY-HO"},
    {Tz::Europe_Minsk, "BY-HR"},
    {Tz::Europe_Minsk, "BY-MA"},
    {Tz::Europe_Minsk, "BY-MI"},
    {Tz::Europe_Minsk, "BY-VI"},
    {Tz::Europe_Moscow},
    {Tz::Europe_Moscow, "RU"},
    {Tz::Europe_Moscow, "RU-AD"},
    {Tz::Europe_Moscow, "RU-ARK"},
    {Tz::Europe_Moscow, "RU-BEL"},
    {Tz::Europe_Moscow, "RU-BRY"},
    {Tz::Europe_Moscow, "RU-CE"},
    {Tz::Europe_Moscow, "RU-CU"},
    {Tz::Europe_Moscow, "RU-DA"},
    {Tz::Europe_Moscow, "RU-IN"},
    {Tz::Europe_Moscow, "RU-IVA"},
    {Tz::Europe_Moscow, "RU-KB"},
    {Tz::Europe_Moscow, "RU-KC"},
    {Tz::Europe_Moscow, "RU-KDA"},
    {Tz::Europe_Moscow, "RU-KL"},
    {Tz::Europe_Moscow, "RU-KLU"},
    {Tz::Europe_Moscow, "RU-KO"},
    {Tz::Europe_Moscow, "RU-KOS"},
    {Tz::Europe_Moscow, "RU-KR"},
    {Tz::Europe_Moscow, "RU-KRS"},
    {Tz::Europe_Moscow, "RU-LEN"},
    {Tz::Europe_Moscow, "RU-LIP"},
    {Tz::Europe_Moscow, "RU-ME"},
    {Tz::Europe_Moscow, "RU-MO"},
    {Tz::Europe_Moscow, "RU-MOS"},
    {Tz::Europe_Moscow, "RU-MOW"},
    {Tz::Europe_Moscow, "RU-MUR"},
    {Tz::Europe_Moscow, "RU-NEN"},
    {Tz::Europe_Moscow, "RU-NGR"},
    {Tz::Europe_Moscow, "RU-NIZ"},
    {Tz::Europe_Moscow, "RU-ORL"},
    {Tz::Europe_Moscow, "RU-PNZ"},
    {Tz::Europe_Moscow, "RU-PSK"},
    {Tz::Europe_Moscow, "RU-ROS"},
    {Tz::Europe_Moscow, "RU-RYA"},
    {Tz::Europe_Moscow, "RU-SE"},
    {Tz::Europe_Moscow, "RU-SMO"},
    {Tz::Europe_Moscow, "RU-SPE"},
    {Tz::Europe_Moscow, "RU-STA"},
    {Tz::Europe_Moscow, "RU-TA"},
    {Tz::Europe_Moscow, "RU-TAM"},
    {Tz::Europe_Moscow, "RU-TUL"},
    {Tz::Europe_Moscow, "RU-TVE"},
    {Tz::Europe_Moscow, "RU-VLA"},
    {Tz::Europe_Moscow, "RU-VLG"},
    {Tz::Europe_Moscow, "RU-VOR"},
    {Tz::Europe_Moscow, "RU-YAR"},
    {Tz::Europe_Oslo},
    {Tz::Europe_Oslo, "NO"},
    {Tz::Europe_Oslo, "NO-03"},
    {Tz::Europe_Oslo, "NO-11"},
    {Tz::Europe_Oslo, "NO-15"},
    {Tz::Europe_Oslo, "NO-18"},
    {Tz::Europe_Oslo, "NO-21"},
    {Tz::Europe_Oslo, "NO-22"},
    {Tz::Europe_Oslo, "NO-30"},
    {Tz::Europe_Oslo, "NO-34"},
    {Tz::Europe_Oslo, "NO-38"},
    {Tz::Europe_Oslo, "NO-42"},
    {Tz::Europe_Oslo, "NO-46"},
    {Tz::Europe_Oslo, "NO-50"},
    {Tz::Europe_Oslo, "NO-54"},
    {Tz::Europe_Paris},
    {Tz::Europe_Paris, "FR"},
    {Tz::Europe_Paris, "FR-ARA"},
    {Tz::Europe_Paris, "FR-BFC"},
    {Tz::Europe_Paris, "FR-BRE"},
    {Tz::Europe_Paris, "FR-COR"},
    {Tz::Europe_Paris, "FR-CVL"},
    {Tz::Europe_Paris, "FR-GES"},
    {Tz::Europe_Paris, "FR-HDF"},
    {Tz::Europe_Paris, "FR-IDF"},
    {Tz::Europe_Paris, "FR-NAQ"},
    {Tz::Europe_Paris, "FR-NOR"},
    {Tz::Europe_Paris, "FR-OCC"},
    {Tz::Europe_Paris, "FR-PAC"},
    {Tz::Europe_Paris, "FR-PDL"},
    {Tz::Europe_Podgorica},
    {Tz::Europe_Podgorica, "ME"},
    {Tz::Europe_Podgorica, "ME-02"},
    {Tz::Europe_Podgorica, "ME-03"},
    {Tz::Europe_Podgorica, "ME-04"},
    {Tz::Europe_Podgorica, "ME-05"},
    {Tz::Europe_Podgorica, "ME-06"},
    {Tz::Europe_Podgorica, "ME-09"},
    {Tz::Europe_Podgorica, "ME-11"},
    {Tz::Europe_Podgorica, "ME-12"},
    {Tz::Europe_Podgorica, "ME-13"},
    {Tz::Europe_Podgorica, "ME-14"},
    {Tz::Europe_Podgorica, "ME-16"},
    {Tz::Europe_Podgorica, "ME-17"},
    {Tz::Europe_Podgorica, "ME-20"},
    {Tz::Europe_Prague},
    {Tz::Europe_Prague, "CZ"},
    {Tz::Europe_Prague, "CZ-10"},
    {Tz::Europe_Prague, "CZ-20"},
    {Tz::Europe_Prague, "CZ-31"},
    {Tz::Europe_Prague, "CZ-32"},
    {Tz::Europe_Prague, "CZ-41"},
    {Tz::Europe_Prague, "CZ-42"},
    {Tz::Europe_Prague, "CZ-51"},
    {Tz::Europe_Prague, "CZ-52"},
    {Tz::Europe_Prague, "CZ-53"},
    {Tz::Europe_Prague, "CZ-63"},
    {Tz::Europe_Prague, "CZ-64"},
    {Tz::Europe_Prague, "CZ-71"},
    {Tz::Europe_Prague, "CZ-72"},
    {Tz::Europe_Prague, "CZ-80"},
    {Tz::Europe_Riga},
    {Tz::Europe_Riga, "LV"},
    {Tz::Europe_Rome},
    {Tz::Europe_Rome, "IT"},
    {Tz::Europe_Rome, "IT-21"},
    {Tz::Europe_Rome, "IT-23"},
    {Tz::Europe_Rome, "IT-25"},
    {Tz::Europe_Rome, "IT-32"},
    {Tz::Europe_Rome, "IT-34"},
    {Tz::Europe_Rome, "IT-42"},
    {Tz::Europe_Rome, "IT-45"},
    {Tz::Europe_Rome, "IT-52"},
    {Tz::Europe_Rome, "IT-55"},
    {Tz::Europe_Rome, "IT-57"},
    {Tz::Europe_Rome, "IT-62"},
    {Tz::Europe_Rome, "IT-65"},
    {Tz::Europe_Rome, "IT-67"},
    {Tz::Europe_Rome, "IT-72"},
    {Tz::Europe_Rome, "IT-75"},
    {Tz::Europe_Rome, "IT-77"},
    {Tz::Europe_Rome, "IT-78"},
    {Tz::Europe_Rome, "IT-82"},
    {Tz::Europe_Rome, "IT-88"},
    {Tz::Europe_Samara, "RU"},
    {Tz::Europe_Samara, "RU-SAM"},
    {Tz::Europe_Samara, "RU-UD"},
    {Tz::Europe_Sarajevo},
    {Tz::Europe_Sarajevo, "BA"},
    {Tz::Europe_Sarajevo, "BA-BIH"},
    {Tz::Europe_Sarajevo, "BA-BRC"},
    {Tz::Europe_Sarajevo, "BA-SRP"},
    {Tz::Europe_Saratov, "RU"},
    {Tz::Europe_Saratov, "RU-SAR"},
    {Tz::Europe_Simferopol},
    {Tz::Europe_Simferopol, "UA-40"},
    {Tz::Europe_Simferopol, "UA-43"},
    {Tz::Europe_Skopje},
    {Tz::Europe_Skopje, "MK"},
    {Tz::Europe_Skopje, "MK-101"},
    {Tz::Europe_Skopje, "MK-104"},
    {Tz::Europe_Skopje, "MK-109"},
    {Tz::Europe_Skopje, "MK-201"},
    {Tz::Europe_Skopje, "MK-202"},
    {Tz::Europe_Skopje, "MK-203"},
    {Tz::Europe_Skopje, "MK-304"},
    {Tz::Europe_Skopje, "MK-307"},
    {Tz::Europe_Skopje, "MK-308"},
    {Tz::Europe_Skopje, "MK-405"},
    {Tz::Europe_Skopje, "MK-501"},
    {Tz::Europe_Skopje, "MK-502"},
    {Tz::Europe_Skopje, "MK-507"},
    {Tz::Europe_Skopje, "MK-508"},
    {Tz::Europe_Skopje, "MK-509"},
    {Tz::Europe_Skopje, "MK-607"},
    {Tz::Europe_Skopje, "MK-701"},
    {Tz::Europe_Skopje, "MK-706"},
    {Tz::Europe_Sofia},
    {Tz::Europe_Sofia, "BG"},
    {Tz::Europe_Sofia, "BG-01"},
    {Tz::Europe_Sofia, "BG-02"},
    {Tz::Europe_Sofia, "BG-03"},
    {Tz::Europe_Sofia, "BG-04"},
    {Tz::Europe_Sofia, "BG-05"},
    {Tz::Europe_Sofia, "BG-06"},
    {Tz::Europe_Sofia, "BG-07"},
    {Tz::Europe_Sofia, "BG-08"},
    {Tz::Europe_Sofia, "BG-09"},
    {Tz::Europe_Sofia, "BG-10"},
    {Tz::Europe_Sofia, "BG-11"},
    {Tz::Europe_Sofia, "BG-12"},
    {Tz::Europe_Sofia, "BG-13"},
    {Tz::Europe_Sofia, "BG-14"},
    {Tz::Europe_Sofia, "BG-15"},
    {Tz::Europe_Sofia, "BG-16"},
    {Tz::Europe_Sofia, "BG-17"},
    {Tz::Europe_Sofia, "BG-18"},
    {Tz::Europe_Sofia, "BG-19"},
    {Tz::Europe_Sofia, "BG-20"},
    {Tz::Europe_Sofia, "BG-21"},
    {Tz::Europe_Sofia, "BG-22"},
    {Tz::Europe_Sofia, "BG-23"},
    {Tz::Europe_Sofia, "BG-24"},
    {Tz::Europe_Sofia, "BG-25"},
    {Tz::Europe_Sofia, "BG-26"},
    {Tz::Europe_Sofia, "BG-27"},
    {Tz::Europe_Sofia, "BG-28"},
    {Tz::Europe_Stockholm},
    {Tz::Europe_Stockholm, "SE"},
    {Tz::Europe_Stockholm, "SE-AB"},
    {Tz::Europe_Stockholm, "SE-AC"},
    {Tz::Europe_Stockholm, "SE-BD"},
    {Tz::Europe_Stockholm, "SE-C"},
    {Tz::Europe_Stockholm, "SE-D"},
    {Tz::Europe_Stockholm, "SE-E"},
    {Tz::Europe_Stockholm, "SE-F"},
    {Tz::Europe_Stockholm, "SE-G"},
    {Tz::Europe_Stockholm, "SE-H"},
    {Tz::Europe_Stockholm, "SE-I"},
    {Tz::Europe_Stockholm, "SE-K"},
    {Tz::Europe_Stockholm, "SE-M"},
    {Tz::Europe_Stockholm, "SE-N"},
    {Tz::Europe_Stockholm, "SE-O"},
    {Tz::Europe_Stockholm, "SE-S"},
    {Tz::Europe_Stockholm, "SE-T"},
    {Tz::Europe_Stockholm, "SE-U"},
    {Tz::Europe_Stockholm, "SE-W"},
    {Tz::Europe_Stockholm, "SE-X"},
    {Tz::Europe_Stockholm, "SE-Y"},
    {Tz::Europe_Stockholm, "SE-Z"},
    {Tz::Europe_Tallinn},
    {Tz::Europe_Tallinn, "EE"},
    {Tz::Europe_Tallinn, "EE-37"},
    {Tz::Europe_Tallinn, "EE-39"},
    {Tz::Europe_Tallinn, "EE-44"},
    {Tz::Europe_Tallinn, "EE-50"},
    {Tz::Europe_Tallinn, "EE-52"},
    {Tz::Europe_Tallinn, "EE-57"},
    {Tz::Europe_Tallinn, "EE-59"},
    {Tz::Europe_Tallinn, "EE-65"},
    {Tz::Europe_Tallinn, "EE-68"},
    {Tz::Europe_Tallinn, "EE-70"},
    {Tz::Europe_Tallinn, "EE-74"},
    {Tz::Europe_Tallinn, "EE-78"},
    {Tz::Europe_Tallinn, "EE-82"},
    {Tz::Europe_Tallinn, "EE-84"},
    {Tz::Europe_Tallinn, "EE-86"},
    {Tz::Europe_Tirane},
    {Tz::Europe_Tirane, "AL"},
    {Tz::Europe_Tirane, "AL-01"},
    {Tz::Europe_Tirane, "AL-02"},
    {Tz::Europe_Tirane, "AL-03"},
    {Tz::Europe_Tirane, "AL-04"},
    {Tz::Europe_Tirane, "AL-05"},
    {Tz::Europe_Tirane, "AL-06"},
    {Tz::Europe_Tirane, "AL-08"},
    {Tz::Europe_Tirane, "AL-09"},
    {Tz::Europe_Tirane, "AL-10"},
    {Tz::Europe_Tirane, "AL-11"},
    {Tz::Europe_Tirane, "AL-12"},
    {Tz::Europe_Ulyanovsk, "RU"},
    {Tz::Europe_Ulyanovsk, "RU-ULY"},
    {Tz::Europe_Uzhgorod},
    {Tz::Europe_Uzhgorod, "UA"},
    {Tz::Europe_Uzhgorod, "UA-21"},
    {Tz::Europe_Vaduz},
    {Tz::Europe_Vienna},
    {Tz::Europe_Vienna, "AT"},
    {Tz::Europe_Vienna, "AT-1"},
    {Tz::Europe_Vienna, "AT-2"},
    {Tz::Europe_Vienna, "AT-3"},
    {Tz::Europe_Vienna, "AT-4"},
    {Tz::Europe_Vienna, "AT-5"},
    {Tz::Europe_Vienna, "AT-6"},
    {Tz::Europe_Vienna, "AT-7"},
    {Tz::Europe_Vienna, "AT-8"},
    {Tz::Europe_Vilnius},
    {Tz::Europe_Vilnius, "LT"},
    {Tz::Europe_Vilnius, "LT-AL"},
    {Tz::Europe_Vilnius, "LT-KL"},
    {Tz::Europe_Vilnius, "LT-KU"},
    {Tz::Europe_Vilnius, "LT-MR"},
    {Tz::Europe_Vilnius, "LT-PN"},
    {Tz::Europe_Vilnius, "LT-SA"},
    {Tz::Europe_Vilnius, "LT-TA"},
    {Tz::Europe_Vilnius, "LT-TE"},
    {Tz::Europe_Vilnius, "LT-UT"},
    {Tz::Europe_Vilnius, "LT-VL"},
    {Tz::Europe_Volgograd, "RU-VGG"},
    {Tz::Europe_Warsaw},
    {Tz::Europe_Warsaw, "PL"},
    {Tz::Europe_Warsaw, "PL-02"},
    {Tz::Europe_Warsaw, "PL-04"},
    {Tz::Europe_Warsaw, "PL-06"},
    {Tz::Europe_Warsaw, "PL-08"},
    {Tz::Europe_Warsaw, "PL-10"},
    {Tz::Europe_Warsaw, "PL-12"},
    {Tz::Europe_Warsaw, "PL-14"},
    {Tz::Europe_Warsaw, "PL-16"},
    {Tz::Europe_Warsaw, "PL-18"},
    {Tz::Europe_Warsaw, "PL-20"},
    {Tz::Europe_Warsaw, "PL-22"},
    {Tz::Europe_Warsaw, "PL-24"},
    {Tz::Europe_Warsaw, "PL-26"},
    {Tz::Europe_Warsaw, "PL-28"},
    {Tz::Europe_Warsaw, "PL-30"},
    {Tz::Europe_Warsaw, "PL-32"},
    {Tz::Europe_Zagreb},
    {Tz::Europe_Zagreb, "HR"},
    {Tz::Europe_Zagreb, "HR-01"},
    {Tz::Europe_Zagreb, "HR-02"},
    {Tz::Europe_Zagreb, "HR-03"},
    {Tz::Europe_Zagreb, "HR-04"},
    {Tz::Europe_Zagreb, "HR-05"},
    {Tz::Europe_Zagreb, "HR-06"},
    {Tz::Europe_Zagreb, "HR-07"},
    {Tz::Europe_Zagreb, "HR-08"},
    {Tz::Europe_Zagreb, "HR-09"},
    {Tz::Europe_Zagreb, "HR-10"},
    {Tz::Europe_Zagreb, "HR-11"},
    {Tz::Europe_Zagreb, "HR-12"},
    {Tz::Europe_Zagreb, "HR-13"},
    {Tz::Europe_Zagreb, "HR-14"},
    {Tz::Europe_Zagreb, "HR-15"},
    {Tz::Europe_Zagreb, "HR-16"},
    {Tz::Europe_Zagreb, "HR-17"},
    {Tz::Europe_Zagreb, "HR-18"},
    {Tz::Europe_Zagreb, "HR-19"},
    {Tz::Europe_Zagreb, "HR-20"},
    {Tz::Europe_Zagreb, "HR-21"},
    {Tz::Europe_Zaporozhye, "UA"},
    {Tz::Europe_Zaporozhye, "UA-23"},
    {Tz::Europe_Zurich},
    {Tz::Europe_Zurich, "CH"},
    {Tz::Europe_Zurich, "CH-AG"},
    {Tz::Europe_Zurich, "CH-BE"},
    {Tz::Europe_Zurich, "CH-FR"},
    {Tz::Europe_Zurich, "CH-GL"},
    {Tz::Europe_Zurich, "CH-GR"},
    {Tz::Europe_Zurich, "CH-JU"},
    {Tz::Europe_Zurich, "CH-LU"},
    {Tz::Europe_Zurich, "CH-NE"},
    {Tz::Europe_Zurich, "CH-OW"},
    {Tz::Europe_Zurich, "CH-SG"},
    {Tz::Europe_Zurich, "CH-SZ"},
    {Tz::Europe_Zurich, "CH-TG"},
    {Tz::Europe_Zurich, "CH-TI"},
    {Tz::Europe_Zurich, "CH-UR"},
    {Tz::Europe_Zurich, "CH-VD"},
    {Tz::Europe_Zurich, "CH-VS"},
    {Tz::Europe_Zurich, "CH-ZG"},
    {Tz::Europe_Zurich, "CH-ZH"},
    {Tz::Indian_Antananarivo, "MG"},
    {Tz::Indian_Antananarivo, "MG-A"},
    {Tz::Indian_Antananarivo, "MG-D"},
    {Tz::Indian_Antananarivo, "MG-F"},
    {Tz::Indian_Antananarivo, "MG-M"},
    {Tz::Indian_Antananarivo, "MG-T"},
    {Tz::Indian_Antananarivo, "MG-U"},
    {Tz::Indian_Chagos, "IO"},
    {Tz::Indian_Christmas, "CX"},
    {Tz::Indian_Cocos, "CC"},
    {Tz::Indian_Comoro, "KM"},
    {Tz::Indian_Comoro, "KM-A"},
    {Tz::Indian_Comoro, "KM-G"},
    {Tz::Indian_Comoro, "KM-M"},
    {Tz::Indian_Kerguelen, "TF"},
    {Tz::Indian_Mahe, "SC"},
    {Tz::Indian_Maldives, "MV"},
    {Tz::Indian_Maldives, "MV-00"},
    {Tz::Indian_Maldives, "MV-01"},
    {Tz::Indian_Maldives, "MV-02"},
    {Tz::Indian_Maldives, "MV-03"},
    {Tz::Indian_Maldives, "MV-04"},
    {Tz::Indian_Maldives, "MV-05"},
    {Tz::Indian_Maldives, "MV-07"},
    {Tz::Indian_Maldives, "MV-08"},
    {Tz::Indian_Maldives, "MV-12"},
    {Tz::Indian_Maldives, "MV-13"},
    {Tz::Indian_Maldives, "MV-14"},
    {Tz::Indian_Maldives, "MV-17"},
    {Tz::Indian_Maldives, "MV-20"},
    {Tz::Indian_Maldives, "MV-23"},
    {Tz::Indian_Maldives, "MV-24"},
    {Tz::Indian_Maldives, "MV-25"},
    {Tz::Indian_Maldives, "MV-26"},
    {Tz::Indian_Maldives, "MV-27"},
    {Tz::Indian_Maldives, "MV-28"},
    {Tz::Indian_Maldives, "MV-29"},
    {Tz::Indian_Mauritius, "MU"},
    {Tz::Indian_Mauritius, "MU-AG"},
    {Tz::Indian_Mauritius, "MU-CC"},
    {Tz::Indian_Mauritius, "MU-FL"},
    {Tz::Indian_Mauritius, "MU-GP"},
    {Tz::Indian_Mauritius, "MU-RO"},
    {Tz::Indian_Mauritius, "MU-RR"},
    {Tz::Indian_Mauritius, "MU-SA"},
    {Tz::Indian_Mayotte},
    {Tz::Indian_Mayotte, "YT"},
    {Tz::Indian_Reunion, "RE"},
    {Tz::Pacific_Apia, "WS"},
    {Tz::Pacific_Auckland, "NZ"},
    {Tz::Pacific_Auckland, "NZ-AUK"},
    {Tz::Pacific_Auckland, "NZ-BOP"},
    {Tz::Pacific_Auckland, "NZ-CAN"},
    {Tz::Pacific_Auckland, "NZ-GIS"},
    {Tz::Pacific_Auckland, "NZ-HKB"},
    {Tz::Pacific_Auckland, "NZ-MBH"},
    {Tz::Pacific_Auckland, "NZ-MWT"},
    {Tz::Pacific_Auckland, "NZ-NSN"},
    {Tz::Pacific_Auckland, "NZ-NTL"},
    {Tz::Pacific_Auckland, "NZ-OTA"},
    {Tz::Pacific_Auckland, "NZ-STL"},
    {Tz::Pacific_Auckland, "NZ-TAS"},
    {Tz::Pacific_Auckland, "NZ-TKI"},
    {Tz::Pacific_Auckland, "NZ-WGN"},
    {Tz::Pacific_Auckland, "NZ-WKO"},
    {Tz::Pacific_Auckland, "NZ-WTC"},
    {Tz::Pacific_Bougainville},
    {Tz::Pacific_Bougainville, "PG"},
    {Tz::Pacific_Bougainville, "PG-NSB"},
    {Tz::Pacific_Chatham, "NZ-CIT"},
    {Tz::Pacific_Chuuk, "FM-TRK"},
    {Tz::Pacific_Chuuk, "FM-YAP"},
    {Tz::Pacific_Easter, "CL-VS"},
    {Tz::Pacific_Efate, "VU"},
    {Tz::Pacific_Efate, "VU-MAP"},
    {Tz::Pacific_Efate, "VU-PAM"},
    {Tz::Pacific_Efate, "VU-SAM"},
    {Tz::Pacific_Efate, "VU-SEE"},
    {Tz::Pacific_Efate, "VU-TAE"},
    {Tz::Pacific_Efate, "VU-TOB"},
    {Tz::Pacific_Enderbury, "KI-P"},
    {Tz::Pacific_Fakaofo, "TK"},
    {Tz::Pacific_Fiji, "FJ"},
    {Tz::Pacific_Fiji, "FJ-C"},
    {Tz::Pacific_Fiji, "FJ-E"},
    {Tz::Pacific_Fiji, "FJ-N"},
    {Tz::Pacific_Fiji, "FJ-R"},
    {Tz::Pacific_Fiji, "FJ-W"},
    {Tz::Pacific_Funafuti, "TV"},
    {Tz::Pacific_Funafuti, "TV-FUN"},
    {Tz::Pacific_Funafuti, "TV-NIT"},
    {Tz::Pacific_Funafuti, "TV-NKF"},
    {Tz::Pacific_Funafuti, "TV-NKL"},
    {Tz::Pacific_Funafuti, "TV-NMA"},
    {Tz::Pacific_Funafuti, "TV-NMG"},
    {Tz::Pacific_Funafuti, "TV-NUI"},
    {Tz::Pacific_Funafuti, "TV-VAI"},
    {Tz::Pacific_Galapagos, "EC-W"},
    {Tz::Pacific_Gambier, "PF"},
    {Tz::Pacific_Guadalcanal},
    {Tz::Pacific_Guadalcanal, "SB"},
    {Tz::Pacific_Guadalcanal, "SB-CE"},
    {Tz::Pacific_Guadalcanal, "SB-CH"},
    {Tz::Pacific_Guadalcanal, "SB-GU"},
    {Tz::Pacific_Guadalcanal, "SB-IS"},
    {Tz::Pacific_Guadalcanal, "SB-MK"},
    {Tz::Pacific_Guadalcanal, "SB-ML"},
    {Tz::Pacific_Guadalcanal, "SB-RB"},
    {Tz::Pacific_Guadalcanal, "SB-TE"},
    {Tz::Pacific_Guadalcanal, "SB-WE"},
    {Tz::Pacific_Guam, "GU"},
    {Tz::Pacific_Guam, "US"},
    {Tz::Pacific_Honolulu, "US"},
    {Tz::Pacific_Honolulu, "US-HI"},
    {Tz::Pacific_Kiritimati, "KI-L"},
    {Tz::Pacific_Kosrae, "FM-KSA"},
    {Tz::Pacific_Kwajalein, "MH-L"},
    {Tz::Pacific_Majuro, "MH-L"},
    {Tz::Pacific_Majuro, "MH-T"},
    {Tz::Pacific_Marquesas, "PF"},
    {Tz::Pacific_Midway, "US"},
    {Tz::Pacific_Midway, "US-HI"},
    {Tz::Pacific_Nauru, "NR"},
    {Tz::Pacific_Niue, "NU"},
    {Tz::Pacific_Norfolk, "NF"},
    {Tz::Pacific_Noumea, "NC"},
    {Tz::Pacific_Pago_Pago, "AS"},
    {Tz::Pacific_Palau, "PW"},
    {Tz::Pacific_Palau, "PW-004"},
    {Tz::Pacific_Palau, "PW-010"},
    {Tz::Pacific_Palau, "PW-050"},
    {Tz::Pacific_Palau, "PW-100"},
    {Tz::Pacific_Palau, "PW-150"},
    {Tz::Pacific_Palau, "PW-214"},
    {Tz::Pacific_Palau, "PW-218"},
    {Tz::Pacific_Palau, "PW-350"},
    {Tz::Pacific_Palau, "PW-370"},
    {Tz::Pacific_Pitcairn, "PN"},
    {Tz::Pacific_Pohnpei, "FM-PNI"},
    {Tz::Pacific_Port_Moresby, "PG"},
    {Tz::Pacific_Port_Moresby, "PG-CPK"},
    {Tz::Pacific_Port_Moresby, "PG-CPM"},
    {Tz::Pacific_Port_Moresby, "PG-EBR"},
    {Tz::Pacific_Port_Moresby, "PG-EHG"},
    {Tz::Pacific_Port_Moresby, "PG-EPW"},
    {Tz::Pacific_Port_Moresby, "PG-ESW"},
    {Tz::Pacific_Port_Moresby, "PG-GPK"},
    {Tz::Pacific_Port_Moresby, "PG-HLA"},
    {Tz::Pacific_Port_Moresby, "PG-JWK"},
    {Tz::Pacific_Port_Moresby, "PG-MBA"},
    {Tz::Pacific_Port_Moresby, "PG-MPL"},
    {Tz::Pacific_Port_Moresby, "PG-MPM"},
    {Tz::Pacific_Port_Moresby, "PG-MRL"},
    {Tz::Pacific_Port_Moresby, "PG-NIK"},
    {Tz::Pacific_Port_Moresby, "PG-NPP"},
    {Tz::Pacific_Port_Moresby, "PG-SAN"},
    {Tz::Pacific_Port_Moresby, "PG-SHM"},
    {Tz::Pacific_Port_Moresby, "PG-WBK"},
    {Tz::Pacific_Port_Moresby, "PG-WHM"},
    {Tz::Pacific_Port_Moresby, "PG-WPD"},
    {Tz::Pacific_Rarotonga, "CK"},
    {Tz::Pacific_Saipan, "MP"},
    {Tz::Pacific_Saipan, "US"},
    {Tz::Pacific_Tahiti, "PF"},
    {Tz::Pacific_Tarawa, "KI-G"},
    {Tz::Pacific_Tongatapu, "TO"},
    {Tz::Pacific_Tongatapu, "TO-01"},
    {Tz::Pacific_Tongatapu, "TO-02"},
    {Tz::Pacific_Tongatapu, "TO-03"},
    {Tz::Pacific_Tongatapu, "TO-04"},
    {Tz::Pacific_Tongatapu, "TO-05"},
    {Tz::Pacific_Wake, "US"},
    {Tz::Pacific_Wallis, "WF"},
};
